@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -62,7 +62,7 @@ namespace ROOT {
       ::ROOT::RBrowserRequest *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(::ROOT::RBrowserRequest));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::RBrowserRequest", "ROOT/RBrowserRequest.hxx", 26,
+         instance("ROOT::RBrowserRequest", "ROOT/RBrowserRequest.hxx", 25,
                   typeid(::ROOT::RBrowserRequest), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLRBrowserRequest_Dictionary, isa_proxy, 4,
                   sizeof(::ROOT::RBrowserRequest) );
@@ -107,7 +107,7 @@ namespace ROOT {
       ::ROOT::RBrowserReply *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(::ROOT::RBrowserReply));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::RBrowserReply", "ROOT/RBrowserReply.hxx", 27,
+         instance("ROOT::RBrowserReply", "ROOT/RBrowserReply.hxx", 26,
                   typeid(::ROOT::RBrowserReply), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLRBrowserReply_Dictionary, isa_proxy, 4,
                   sizeof(::ROOT::RBrowserReply) );
@@ -152,7 +152,7 @@ namespace ROOT {
       ::ROOT::RBrowserData *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(::ROOT::RBrowserData));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::RBrowserData", "ROOT/RBrowserData.hxx", 35,
+         instance("ROOT::RBrowserData", "ROOT/RBrowserData.hxx", 34,
                   typeid(::ROOT::RBrowserData), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLRBrowserData_Dictionary, isa_proxy, 4,
                   sizeof(::ROOT::RBrowserData) );
@@ -197,7 +197,7 @@ namespace ROOT {
       ::ROOT::RBrowser *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(::ROOT::RBrowser));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::RBrowser", "ROOT/RBrowser.hxx", 27,
+         instance("ROOT::RBrowser", "ROOT/RBrowser.hxx", 26,
                   typeid(::ROOT::RBrowser), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLRBrowser_Dictionary, isa_proxy, 4,
                   sizeof(::ROOT::RBrowser) );
@@ -242,7 +242,7 @@ namespace ROOT {
       ::ROOT::RFileDialog *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TIsAProxy(typeid(::ROOT::RFileDialog));
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::RFileDialog", "ROOT/RFileDialog.hxx", 41,
+         instance("ROOT::RFileDialog", "ROOT/RFileDialog.hxx", 40,
                   typeid(::ROOT::RFileDialog), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &ROOTcLcLRFileDialog_Dictionary, isa_proxy, 4,
                   sizeof(::ROOT::RFileDialog) );
@@ -285,7 +285,7 @@ namespace ROOT {
       ::ROOT::RWebBrowserImp *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::ROOT::RWebBrowserImp >(nullptr);
       static ::ROOT::TGenericClassInfo 
-         instance("ROOT::RWebBrowserImp", ::ROOT::RWebBrowserImp::Class_Version(), "ROOT/RWebBrowserImp.hxx", 22,
+         instance("ROOT::RWebBrowserImp", ::ROOT::RWebBrowserImp::Class_Version(), "ROOT/RWebBrowserImp.hxx", 21,
                   typeid(::ROOT::RWebBrowserImp), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &::ROOT::RWebBrowserImp::Dictionary, isa_proxy, 4,
                   sizeof(::ROOT::RWebBrowserImp) );
@@ -632,22 +632,24 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libROOTBrowserv7 dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RBrowserRequest.hxx")))  __attribute__((annotate("$clingAutoload$ROOT/RBrowser.hxx")))  RBrowserRequest;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RBrowserReply.hxx")))  __attribute__((annotate("$clingAutoload$ROOT/RBrowser.hxx")))  RBrowserReply;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RBrowserData.hxx")))  __attribute__((annotate("$clingAutoload$ROOT/RBrowser.hxx")))  RBrowserData;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RBrowser.hxx")))  RBrowser;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RFileDialog.hxx")))  RFileDialog;}
-namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RWebBrowserImp.hxx")))  RWebBrowserImp;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RBrowserRequest.hxx")))  __attribute__((annotate("$clingAutoload$ROOT/RBrowser.hxx")))  RBrowserRequest;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RBrowserReply.hxx")))  __attribute__((annotate("$clingAutoload$ROOT/RBrowser.hxx")))  RBrowserReply;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RBrowserData.hxx")))  __attribute__((annotate("$clingAutoload$ROOT/RBrowser.hxx")))  RBrowserData;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RBrowser.hxx")))  RBrowser;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RFileDialog.hxx")))  RFileDialog;}
+namespace ROOT{class  __attribute__((annotate("$clingAutoload$ROOT/RWebBrowserImp.hxx")))  RWebBrowserImp;}
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libROOTBrowserv7 dictionary payload"
@@ -661,6 +663,9 @@ namespace ROOT{class __attribute__((annotate("$clingAutoload$ROOT/RWebBrowserImp
 #ifndef NO_SSL_DL
   #define NO_SSL_DL 1
 #endif
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
