@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -742,25 +742,25 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include/freetype2",
-"/usr/include",
-"/usr/include/freetype2",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libGuiBld dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-class __attribute__((annotate("$clingAutoload$TGuiBldDragManager.h")))  TGuiBldDragManager;
-class __attribute__((annotate("$clingAutoload$TGuiBldEditor.h")))  TGuiBldEditor;
-class __attribute__((annotate("$clingAutoload$TGuiBldGeometryFrame.h")))  TGuiBldGeometryFrame;
-class __attribute__((annotate("$clingAutoload$TGuiBldHintsButton.h")))  TGuiBldHintsButton;
-class __attribute__((annotate("$clingAutoload$TGuiBldHintsEditor.h")))  TGuiBldHintsEditor;
-class __attribute__((annotate("$clingAutoload$TGuiBldNameFrame.h")))  TGuiBldNameFrame;
-class __attribute__((annotate("$clingAutoload$TRootGuiBuilder.h")))  TRootGuiBuilder;
+class  __attribute__((annotate("$clingAutoload$TGuiBldDragManager.h")))  TGuiBldDragManager;
+class  __attribute__((annotate("$clingAutoload$TGuiBldEditor.h")))  TGuiBldEditor;
+class  __attribute__((annotate("$clingAutoload$TGuiBldGeometryFrame.h")))  TGuiBldGeometryFrame;
+class  __attribute__((annotate("$clingAutoload$TGuiBldHintsButton.h")))  TGuiBldHintsButton;
+class  __attribute__((annotate("$clingAutoload$TGuiBldHintsEditor.h")))  TGuiBldHintsEditor;
+class  __attribute__((annotate("$clingAutoload$TGuiBldNameFrame.h")))  TGuiBldNameFrame;
+class  __attribute__((annotate("$clingAutoload$TRootGuiBuilder.h")))  TRootGuiBuilder;
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libGuiBld dictionary payload"
@@ -768,6 +768,9 @@ class __attribute__((annotate("$clingAutoload$TRootGuiBuilder.h")))  TRootGuiBui
 #ifndef ROOT_SUPPORT_CLAD
   #define ROOT_SUPPORT_CLAD 1
 #endif
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
