@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -1735,32 +1735,34 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libWebGui6 dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-class __attribute__((annotate("$clingAutoload$TWebPadOptions.h")))  __attribute__((annotate("$clingAutoload$TWebCanvas.h")))  TWebObjectOptions;
-class __attribute__((annotate("$clingAutoload$TWebPadOptions.h")))  __attribute__((annotate("$clingAutoload$TWebCanvas.h")))  TWebPadOptions;
-class __attribute__((annotate("$clingAutoload$TWebPadOptions.h")))  __attribute__((annotate("$clingAutoload$TWebCanvas.h")))  TWebPadClick;
-class __attribute__((annotate("$clingAutoload$TWebCanvas.h")))  TWebCanvas;
-class __attribute__((annotate("$clingAutoload$TWebControlBar.h")))  TWebControlBar;
-class __attribute__((annotate("$clingAutoload$TWebMenuItem.h")))  TWebMenuItem;
-class __attribute__((annotate("$clingAutoload$TWebMenuItem.h")))  TWebCheckedMenuItem;
-class __attribute__((annotate("$clingAutoload$TWebMenuItem.h")))  TWebMenuArgument;
-class __attribute__((annotate("$clingAutoload$TWebMenuItem.h")))  TWebArgsMenuItem;
-class __attribute__((annotate("$clingAutoload$TWebMenuItem.h")))  TWebMenuItems;
-class __attribute__((annotate("$clingAutoload$TWebPainting.h")))  __attribute__((annotate("$clingAutoload$TWebPadPainter.h")))  TWebPainting;
-class __attribute__((annotate("$clingAutoload$TWebPadPainter.h")))  TWebPadPainter;
-class __attribute__((annotate("$clingAutoload$TWebPS.h")))  TWebPS;
-class __attribute__((annotate("$clingAutoload$TWebSnapshot.h")))  TWebSnapshot;
-class __attribute__((annotate("$clingAutoload$TWebSnapshot.h")))  TPadWebSnapshot;
-class __attribute__((annotate("$clingAutoload$TWebSnapshot.h")))  TCanvasWebSnapshot;
+class  __attribute__((annotate("$clingAutoload$TWebPadOptions.h")))  __attribute__((annotate("$clingAutoload$TWebCanvas.h")))  TWebObjectOptions;
+class  __attribute__((annotate("$clingAutoload$TWebPadOptions.h")))  __attribute__((annotate("$clingAutoload$TWebCanvas.h")))  TWebPadOptions;
+class  __attribute__((annotate("$clingAutoload$TWebPadOptions.h")))  __attribute__((annotate("$clingAutoload$TWebCanvas.h")))  TWebPadClick;
+class  __attribute__((annotate("$clingAutoload$TWebCanvas.h")))  TWebCanvas;
+class  __attribute__((annotate("$clingAutoload$TWebControlBar.h")))  TWebControlBar;
+class  __attribute__((annotate("$clingAutoload$TWebMenuItem.h")))  TWebMenuItem;
+class  __attribute__((annotate("$clingAutoload$TWebMenuItem.h")))  TWebCheckedMenuItem;
+class  __attribute__((annotate("$clingAutoload$TWebMenuItem.h")))  TWebMenuArgument;
+class  __attribute__((annotate("$clingAutoload$TWebMenuItem.h")))  TWebArgsMenuItem;
+class  __attribute__((annotate("$clingAutoload$TWebMenuItem.h")))  TWebMenuItems;
+class  __attribute__((annotate("$clingAutoload$TWebPainting.h")))  __attribute__((annotate("$clingAutoload$TWebPadPainter.h")))  TWebPainting;
+class  __attribute__((annotate("$clingAutoload$TWebPadPainter.h")))  TWebPadPainter;
+class  __attribute__((annotate("$clingAutoload$TWebPS.h")))  TWebPS;
+class  __attribute__((annotate("$clingAutoload$TWebSnapshot.h")))  TWebSnapshot;
+class  __attribute__((annotate("$clingAutoload$TWebSnapshot.h")))  TPadWebSnapshot;
+class  __attribute__((annotate("$clingAutoload$TWebSnapshot.h")))  TCanvasWebSnapshot;
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libWebGui6 dictionary payload"
@@ -1774,6 +1776,9 @@ class __attribute__((annotate("$clingAutoload$TWebSnapshot.h")))  TCanvasWebSnap
 #ifndef NO_SSL_DL
   #define NO_SSL_DL 1
 #endif
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
