@@ -13,14 +13,19 @@
 #include "clad/Differentiator/DiffPlanner.h"
 #include "clad/Differentiator/ErrorEstimator.h"
 #include "clad/Differentiator/ParseDiffArgsTypes.h"
+#include "clad/Differentiator/VisitorBase.h"
 
 #include "clang/AST/ASTContext.h"
 #include "clang/AST/ASTLambda.h"
 #include "clang/AST/Decl.h"
 #include "clang/AST/Expr.h"
+#include "clang/AST/ExprCXX.h"
 #include "clang/AST/OperationKinds.h"
 #include "clang/AST/TemplateBase.h"
 #include "clang/AST/Type.h"
+#include "clang/Basic/LLVM.h"
+#include "clang/Basic/SourceLocation.h"
+#include "clang/Basic/TokenKinds.h"
 #include "clang/Sema/Lookup.h"
 #include "clang/Sema/Overload.h"
 #include "clang/Sema/Scope.h"
@@ -50,21 +55,6 @@ BaseForwardModeVisitor::BaseForwardModeVisitor(DerivativeBuilder& builder,
 
 BaseForwardModeVisitor::~BaseForwardModeVisitor() {}
 
-bool BaseForwardModeVisitor::IsDifferentiableType(QualType T) {
-  QualType origType = T;
-  // FIXME: arbitrary dimension array type as well.
-  while (utils::isArrayOrPointerType(T))
-    T = utils::GetValueType(T);
-  T = T.getNonReferenceType();
-  if (T->isEnumeralType())
-    return false;
-  if (T->isRealType() || T->isStructureOrClassType())
-    return true;
-  if (origType->isPointerType() && T->isVoidType())
-    return true;
-  return false;
-}
-
 bool IsRealNonReferenceType(QualType T) {
   return T.getNonReferenceType()->isRealType();
 }
@@ -72,11 +62,14 @@ bool IsRealNonReferenceType(QualType T) {
 DerivativeAndOverload BaseForwardModeVisitor::Derive() {
   const FunctionDecl* FD = m_DiffReq.Function;
   assert(m_DiffReq.Mode == DiffMode::forward ||
-         m_DiffReq.Mode == DiffMode::experimental_pushforward ||
-         m_DiffReq.Mode == DiffMode::experimental_vector_pushforward);
+         m_DiffReq.Mode == DiffMode::pushforward ||
+         m_DiffReq.Mode == DiffMode::vector_pushforward);
   assert(!m_DerivativeInFlight &&
          "Doesn't support recursive diff. Use DiffPlan.");
 
+  PrettyStackTraceDerivative CrashInfo(m_DiffReq, m_Blocks, m_Sema,
+                                       &m_CurVisitedStmt);
+
   llvm::SaveAndRestore<bool> saveInFlight(m_DerivativeInFlight,
                                           /*NewValue=*/true);
 
@@ -151,9 +144,6 @@ DerivativeAndOverload BaseForwardModeVisitor::Derive() {
   // FIXME: We should not use const_cast to get the decl context here.
   // NOLINTNEXTLINE(cppcoreguidelines-pro-type-const-cast)
   auto* DC = const_cast<DeclContext*>(m_DiffReq->getDeclContext());
-  if (FunctionDecl* customDerivative =
-          m_Builder.LookupCustomDerivativeDecl(gradientName, DC, FD->getType()))
-    return DerivativeAndOverload{customDerivative, nullptr};
 
   IdentifierInfo* II = &m_Context.Idents.get(gradientName);
   SourceLocation validLoc{m_DiffReq->getLocation()};
@@ -162,7 +152,7 @@ DerivativeAndOverload BaseForwardModeVisitor::Derive() {
   llvm::SaveAndRestore<Scope*> SaveScope(getCurrentScope());
 
   m_Sema.CurContext = DC;
-  QualType derivedFnType = ComputeDerivativeFunctionType();
+  QualType derivedFnType = GetDerivativeType();
   DeclWithContext result =
       m_Builder.cloneFunction(FD, *this, DC, validLoc, name, derivedFnType);
   FunctionDecl* derivedFD = result.first;
@@ -176,18 +166,23 @@ DerivativeAndOverload BaseForwardModeVisitor::Derive() {
 
   llvm::SmallVector<ParmVarDecl*, 16> params;
   SetupDerivativeParameters(params);
-  derivedFD->setParams(params);
 
-  derivedFD->setBody(nullptr);
+  m_Derivative->setParams(params);
+  m_Derivative->setBody(nullptr);
+
+  m_Sema.PopFunctionScopeInfo();
+  m_Sema.PopDeclContext();
 
   if (!m_DiffReq.DeclarationOnly) {
+    m_Sema.ActOnStartOfFunctionDef(getCurrentScope(), m_Derivative);
+
     // Function body scope
     beginScope(Scope::FnScope | Scope::DeclScope);
     m_DerivativeFnScope = getCurrentScope();
     beginBlock();
 
     // FIXME: Remove the override in VectorPushForwardModeVisitor.
-    if (m_DiffReq.Mode == DiffMode::experimental_vector_pushforward)
+    if (m_DiffReq.Mode == DiffMode::vector_pushforward)
       ExecuteInsidePushforwardFunctionBlock();
 
     if (m_DiffReq.Mode == DiffMode::forward)
@@ -199,8 +194,14 @@ DerivativeAndOverload BaseForwardModeVisitor::Derive() {
         addToCurrentBlock(S);
     else
       addToCurrentBlock(BodyDiff);
-    Stmt* derivativeBody = endBlock();
-    derivedFD->setBody(derivativeBody);
+    Stmt* fnBody = endBlock();
+    // FIXME: Enable this when we vgvassilev/clad#367 (removing goto stmts).
+    // // If ActOnFinishFunctionBody should pop the current DeclContext.
+    // bool IsInstantiation = false;
+    // m_Sema.ActOnFinishFunctionBody(m_Derivative, fnBody, IsInstantiation);
+    m_Derivative->setBody(fnBody);
+    m_Sema.PopFunctionScopeInfo();
+    m_Sema.PopDeclContext();
     endScope(); // Function body scope
   }
 
@@ -225,68 +226,37 @@ DerivativeAndOverload BaseForwardModeVisitor::Derive() {
     }
   }
 
-  m_Sema.PopFunctionScopeInfo();
-  m_Sema.PopDeclContext();
   endScope(); // Function decl scope
 
   return DerivativeAndOverload{result.first,
                                /*OverloadFunctionDecl=*/nullptr};
 }
 
-QualType BaseForwardModeVisitor::ComputeDerivativeFunctionType() {
-  const FunctionDecl* FD = m_DiffReq.Function;
-
-  if (m_DiffReq.Mode == DiffMode::forward)
-    return FD->getType();
-
-  assert(m_DiffReq.Mode == GetPushForwardMode());
-
-  const auto* FnProtoTy = cast<FunctionProtoType>(FD->getType());
-  llvm::SmallVector<QualType, 16> FnTypes(FnProtoTy->getParamTypes().begin(),
-                                          FnProtoTy->getParamTypes().end());
-
-  bool HasThis = false;
-  if (const auto* MD = dyn_cast<CXXMethodDecl>(FD)) {
-    if (MD->isInstance()) {
-      FnTypes.push_back(MD->getThisType());
-      HasThis = true;
-    }
-  }
-
-  // Iterate over all but the "this" type and extend the signature to add the
-  // extra parameters.
-  for (size_t i = 0, e = FnTypes.size() - HasThis; i < e; ++i) {
-    QualType PVDTy = FnTypes[i];
-    if (BaseForwardModeVisitor::IsDifferentiableType(PVDTy))
-      FnTypes.push_back(GetPushForwardDerivativeType(PVDTy));
-  }
-
-  QualType oRetTy = FD->getReturnType();
-  QualType dRetTy;
-  if (oRetTy->isVoidType()) {
-    dRetTy = m_Context.VoidTy;
-  } else {
-    TemplateDecl* valueAndPushforward =
-        LookupTemplateDeclInCladNamespace("ValueAndPushforward");
-    assert(valueAndPushforward &&
-           "clad::ValueAndPushforward template not found!!");
-    // FIXME: Sink GetPushForwardDerivativeType here.
-    QualType PushFwdTy = GetPushForwardDerivativeType(oRetTy);
-    dRetTy = InstantiateTemplate(valueAndPushforward, {oRetTy, PushFwdTy});
-  }
-  FunctionProtoType::ExtProtoInfo EPI = FnProtoTy->getExtProtoInfo();
-  return m_Context.getFunctionType(dRetTy, FnTypes, EPI);
-}
-
 void BaseForwardModeVisitor::SetupDerivativeParameters(
     llvm::SmallVectorImpl<ParmVarDecl*>& params) {
   const FunctionDecl* FD = m_DiffReq.Function;
-  for (ParmVarDecl* PVD : FD->parameters()) {
+  const FunctionDecl* FDPattern = nullptr;
+  unsigned FDPatternNumParams = 0;
+  if (FD->isTemplateInstantiation()) {
+    FDPattern = FD->getTemplateInstantiationPattern();
+    FDPatternNumParams = FDPattern->getNumParams();
+  }
+  for (unsigned i = 0, n = FD->getNumParams(); i < n; ++i) {
+    const ParmVarDecl* PVD = FD->getParamDecl(i);
     IdentifierInfo* PVDII = PVD->getIdentifier();
     // Implicitly created special member functions have no parameter names.
     if (!PVD->getDeclName())
       PVDII = CreateUniqueIdentifier("param");
 
+    if (FDPattern) {
+      const ParmVarDecl* OrigPVD =
+          i >= FDPatternNumParams
+              ? FDPattern->getParamDecl(FDPatternNumParams - 1)
+              : FDPattern->getParamDecl(i);
+      if (OrigPVD->isParameterPack())
+        PVDII = CreateUniqueIdentifier(PVDII->getName());
+    }
+
     auto* newPVD = CloneParmVarDecl(PVD, PVDII,
                                     /*pushOnScopeChains=*/true,
                                     /*cloneDefaultArg=*/false);
@@ -295,7 +265,8 @@ void BaseForwardModeVisitor::SetupDerivativeParameters(
     if (PVD == m_IndependentVar)
       m_IndependentVar = newPVD;
 
-    if (!PVD->getDeclName()) // We can't use lookup-based replacements
+    // We can't use lookup-based replacements
+    if (PVD->getDeclName() != newPVD->getDeclName())
       m_DeclReplacements[PVD] = newPVD;
 
     params.push_back(newPVD);
@@ -309,7 +280,8 @@ void BaseForwardModeVisitor::SetupDerivativeParameters(
   // parameter for representing derivative of `this` pointer with respect to the
   // independent parameter.
   if (const auto* MD = dyn_cast<CXXMethodDecl>(FD)) {
-    if (MD->isInstance()) {
+    const CXXRecordDecl* RD = MD->getParent();
+    if (MD->isInstance() && !RD->isLambda()) {
       IdentifierInfo* dThisII = &m_Context.Idents.get("_d_this");
       auto* dPVD = utils::BuildParmVarDecl(m_Sema, m_Sema.CurContext, dThisII,
                                            MD->getThisType());
@@ -324,13 +296,14 @@ void BaseForwardModeVisitor::SetupDerivativeParameters(
   for (size_t i = 0, e = params.size() - HasThis; i < e; ++i) {
     const ParmVarDecl* PVD = params[i];
 
-    if (!BaseForwardModeVisitor::IsDifferentiableType(PVD->getType()))
+    if (!utils::IsDifferentiableType(PVD->getType()))
       continue;
 
     IdentifierInfo* II = &m_Context.Idents.get("_d_" + PVD->getNameAsString());
-    auto* dPVD = utils::BuildParmVarDecl(
-        m_Sema, m_Derivative, II, GetPushForwardDerivativeType(PVD->getType()),
-        PVD->getStorageClass());
+    QualType diffTy = utils::GetParameterDerivativeType(m_Sema, m_DiffReq.Mode,
+                                                        PVD->getType());
+    auto* dPVD = utils::BuildParmVarDecl(m_Sema, m_Derivative, II, diffTy,
+                                         PVD->getStorageClass());
     params.push_back(dPVD);
     m_Variables[PVD] = BuildDeclRef(dPVD);
   }
@@ -345,7 +318,7 @@ void BaseForwardModeVisitor::GenerateSeeds(const clang::FunctionDecl* dFD) {
     // non-reference type for creating the derivatives.
     QualType dParamType = param->getType().getNonReferenceType();
     // We do not create derived variable for array/pointer parameters.
-    if (!BaseForwardModeVisitor::IsDifferentiableType(dParamType) ||
+    if (!utils::IsDifferentiableType(dParamType) ||
         utils::isArrayOrPointerType(dParamType))
       continue;
     Expr* dParam = nullptr;
@@ -827,8 +800,7 @@ StmtDiff BaseForwardModeVisitor::VisitMemberExpr(const MemberExpr* ME) {
       return {clonedME, zero};
     auto baseDiff = Visit(ME->getBase());
     // No derivative found for base. Therefore, derivative is 0.
-    if (isa<IntegerLiteral>(baseDiff.getExpr_dx()) ||
-        isa<FloatingLiteral>(baseDiff.getExpr_dx()))
+    if (baseDiff.getExpr_dx()->getType()->isVoidType())
       return {clonedME, zero};
 
     auto field = ME->getMemberDecl();
@@ -988,9 +960,12 @@ StmtDiff BaseForwardModeVisitor::VisitDeclRefExpr(const DeclRefExpr* DRE) {
   // If DRE is of type pointer, then the derivative is a null pointer.
   if (clonedDRE->getType()->isPointerType())
     return StmtDiff(clonedDRE, nullptr);
-  QualType literalTy = utils::GetValueType(clonedDRE->getType());
-  return StmtDiff(clonedDRE, ConstantFolder::synthesizeLiteral(
-                                 literalTy, m_Context, /*val=*/0));
+
+  if (const auto* decl = dyn_cast<VarDecl>(DRE->getDecl()))
+    if (!m_DiffReq.shouldHaveAdjointForw(decl))
+      return StmtDiff(clonedDRE, nullptr);
+
+  return StmtDiff(clonedDRE, getZeroInit(clonedDRE->getType()));
 }
 
 StmtDiff BaseForwardModeVisitor::VisitIntegerLiteral(const IntegerLiteral* IL) {
@@ -1008,17 +983,12 @@ BaseForwardModeVisitor::VisitFloatingLiteral(const FloatingLiteral* FL) {
   return StmtDiff(Clone(FL), constant0);
 }
 
-QualType
-BaseForwardModeVisitor::GetPushForwardDerivativeType(QualType ParamType) {
-  return ParamType;
-}
-
 std::string BaseForwardModeVisitor::GetPushForwardFunctionSuffix() {
   return "_pushforward";
 }
 
 DiffMode BaseForwardModeVisitor::GetPushForwardMode() {
-  return DiffMode::experimental_pushforward;
+  return DiffMode::pushforward;
 }
 
 StmtDiff BaseForwardModeVisitor::VisitCallExpr(const CallExpr* CE) {
@@ -1034,6 +1004,10 @@ StmtDiff BaseForwardModeVisitor::VisitCallExpr(const CallExpr* CE) {
   // Calls to lambda functions are processed differently
   bool isLambda = isLambdaCallOperator(FD);
 
+  Expr* CUDAExecConfig = nullptr;
+  if (const auto* KCE = dyn_cast<CUDAKernelCallExpr>(CE))
+    CUDAExecConfig = Clone(KCE->getConfig());
+
   // If the function is non_differentiable, return zero derivative.
   if (clad::utils::hasNonDifferentiableAttribute(CE)) {
     // Calling the function without computing derivatives
@@ -1041,10 +1015,11 @@ StmtDiff BaseForwardModeVisitor::VisitCallExpr(const CallExpr* CE) {
     for (unsigned i = 0, e = CE->getNumArgs(); i < e; ++i)
       ClonedArgs.push_back(Clone(CE->getArg(i)));
 
-    Expr* Call = m_Sema
-                     .ActOnCallExpr(getCurrentScope(), Clone(CE->getCallee()),
-                                    validLoc, ClonedArgs, validLoc)
-                     .get();
+    Expr* Call =
+        m_Sema
+            .ActOnCallExpr(getCurrentScope(), Clone(CE->getCallee()), validLoc,
+                           ClonedArgs, validLoc, CUDAExecConfig)
+            .get();
     // Creating a zero derivative
     auto* zero =
         ConstantFolder::synthesizeLiteral(m_Context.IntTy, m_Context, 0);
@@ -1062,16 +1037,8 @@ StmtDiff BaseForwardModeVisitor::VisitCallExpr(const CallExpr* CE) {
   StmtDiff baseDiff;
   // Add derivative of the implicit `this` pointer to the `diffArgs`.
   if (isLambda) {
-    if (const auto* OCE = dyn_cast<CXXOperatorCallExpr>(CE)) {
-      QualType ptrType = m_Context.getPointerType(m_Context.getRecordType(
-          FD->getDeclContext()->getOuterLexicalRecordContext()));
-      // For now, only lambdas with no captures are supported, so we just pass
-      // a nullptr instead of the diff object.
-      baseDiff =
-          StmtDiff(Clone(OCE->getArg(0)),
-                   new (m_Context) CXXNullPtrLiteralExpr(ptrType, validLoc));
-      diffArgs.push_back(baseDiff.getExpr_dx());
-    }
+    if (const auto* OCE = dyn_cast<CXXOperatorCallExpr>(CE))
+      baseDiff = Clone(OCE->getArg(0));
   } else if (const auto* MD =
                  dyn_cast<CXXMethodDecl>(FD)) { // isLambda == false
     if (MD->isInstance()) {
@@ -1104,6 +1071,7 @@ StmtDiff BaseForwardModeVisitor::VisitCallExpr(const CallExpr* CE) {
     skipFirstArg = true;
 
   // For f(g(x)) = f'(x) * g'(x)
+  std::size_t numParams = FD->getNumParams();
   Expr* Multiplier = nullptr;
   for (size_t i = skipFirstArg, e = CE->getNumArgs(); i < e; ++i) {
     const Expr* arg = CE->getArg(i);
@@ -1112,7 +1080,11 @@ StmtDiff BaseForwardModeVisitor::VisitCallExpr(const CallExpr* CE) {
     // If original argument is an RValue and function expects an RValue
     // parameter, then convert the cloned argument and the corresponding
     // derivative to RValue if they are not RValue.
-    QualType paramType = FD->getParamDecl(i - skipFirstArg)->getType();
+    QualType paramType;
+    if (FD->isVariadic() && (i - skipFirstArg) >= numParams)
+      paramType = CE->getArg(i - skipFirstArg)->getType();
+    else
+      paramType = FD->getParamDecl(i - skipFirstArg)->getType();
     if (utils::IsRValue(arg) && paramType->isRValueReferenceType()) {
       if (!utils::IsRValue(argDiff.getExpr())) {
         Expr* castE = utils::BuildStaticCastToRValue(m_Sema, argDiff.getExpr());
@@ -1125,8 +1097,10 @@ StmtDiff BaseForwardModeVisitor::VisitCallExpr(const CallExpr* CE) {
       }
     }
     CallArgs.push_back(argDiff.getExpr());
-    if (BaseForwardModeVisitor::IsDifferentiableType(arg->getType())) {
+    if (utils::IsDifferentiableType(arg->getType())) {
       Expr* dArg = argDiff.getExpr_dx();
+      if (!dArg)
+        dArg = getZeroInit(arg->getType());
       // FIXME: What happens when dArg is nullptr?
       diffArgs.push_back(dArg);
     }
@@ -1138,52 +1112,19 @@ StmtDiff BaseForwardModeVisitor::VisitCallExpr(const CallExpr* CE) {
   pushforwardFnArgs.insert(pushforwardFnArgs.end(), diffArgs.begin(),
                            diffArgs.end());
 
-  auto customDerivativeArgs = pushforwardFnArgs;
-
-  if (Expr* baseE = baseDiff.getExpr()) {
-    if (!baseE->getType()->isPointerType())
-      baseE = BuildOp(UnaryOperatorKind::UO_AddrOf, baseE);
-    customDerivativeArgs.insert(customDerivativeArgs.begin(), baseE);
-  }
-
-  // Try to find a user-defined overloaded derivative.
   Expr* callDiff = nullptr;
-  std::string customPushforward =
-      clad::utils::ComputeEffectiveFnName(FD) + GetPushForwardFunctionSuffix();
-  callDiff = m_Builder.BuildCallToCustomDerivativeOrNumericalDiff(
-      customPushforward, customDerivativeArgs, getCurrentScope(), CE);
-  // Custom derivative templates can be written in a
-  // general way that works for both vectorized and non-vectorized
-  // modes. We have to also look for the pushforward with the regular name.
-  if (!callDiff && m_DiffReq.Mode != DiffMode::forward) {
-    customPushforward =
-        clad::utils::ComputeEffectiveFnName(FD) + "_pushforward";
-    callDiff = m_Builder.BuildCallToCustomDerivativeOrNumericalDiff(
-        customPushforward, customDerivativeArgs, getCurrentScope(), CE);
-  }
-  if (!isLambda) {
-    // Check if it is a recursive call.
-    if (!callDiff && (FD == m_DiffReq.Function) &&
-        m_DiffReq.Mode == GetPushForwardMode()) {
-      // The differentiated function is called recursively.
-      Expr* derivativeRef =
-          m_Sema
-              .BuildDeclarationNameExpr(
-                  CXXScopeSpec(), m_Derivative->getNameInfo(), m_Derivative)
-              .get();
-      callDiff = m_Sema
-                     .ActOnCallExpr(
-                         m_Sema.getScopeForContext(m_Sema.CurContext),
-                         derivativeRef, validLoc, pushforwardFnArgs, validLoc)
-                     .get();
-    }
-  }
-
+  // FIXME: Move non-differentiable function handling to the DiffPlanner.
   // If all arguments are constant literals, then this does not contribute to
   // the gradient.
   // FIXME: revert this when this is integrated in the activity analysis pass.
+
+  QualType returnType = FD->getReturnType();
+  // FIXME: Decide this in the diff planner
+  bool needsForwPass =
+      utils::isNonConstReferenceType(returnType) || returnType->isPointerType();
   if (!callDiff) {
-    if (!isa<CXXOperatorCallExpr>(CE) && !isa<CXXMemberCallExpr>(CE)) {
+    if (!isa<CXXOperatorCallExpr>(CE) && !isa<CXXMemberCallExpr>(CE) &&
+        !needsForwPass) {
       bool allArgsHaveZeroDerivatives = true;
       for (unsigned i = 0, e = CE->getNumArgs(); i < e; ++i) {
         Expr* dArg = diffArgs[i];
@@ -1199,7 +1140,7 @@ StmtDiff BaseForwardModeVisitor::VisitCallExpr(const CallExpr* CE) {
             m_Sema
                 .ActOnCallExpr(getCurrentScope(), Clone(CE->getCallee()),
                                validLoc, llvm::MutableArrayRef<Expr*>(CallArgs),
-                               validLoc)
+                               validLoc, CUDAExecConfig)
                 .get();
         auto* zero = getZeroInit(CE->getType());
         return StmtDiff(call, zero);
@@ -1216,26 +1157,28 @@ StmtDiff BaseForwardModeVisitor::VisitCallExpr(const CallExpr* CE) {
     pushforwardFnRequest.BaseFunctionName = utils::ComputeEffectiveFnName(FD);
     // Silence diag outputs in nested derivation process.
     pushforwardFnRequest.VerboseDiags = false;
+    pushforwardFnRequest.EnableTBRAnalysis = m_DiffReq.EnableTBRAnalysis;
+    pushforwardFnRequest.EnableVariedAnalysis = m_DiffReq.EnableVariedAnalysis;
 
-    // Check if request already derived in DerivedFunctions.
-    FunctionDecl* pushforwardFD =
-        m_Builder.HandleNestedDiffRequest(pushforwardFnRequest);
-
+    FunctionDecl* pushforwardFD = nullptr;
+    if (m_DiffReq.CurrentDerivativeOrder != 1 || !m_DiffReq.CallContext) {
+      callDiff = m_Builder.BuildCallToCustomDerivativeOrNumericalDiff(
+          pushforwardFnRequest.ComputeDerivativeName(), pushforwardFnArgs,
+          getCurrentScope(), CE,
+          /*forCustomDerv=*/true, /*namespaceShouldExist=*/true,
+          CUDAExecConfig);
+      if (auto* foundCE = cast_or_null<CallExpr>(callDiff))
+        pushforwardFD = foundCE->getDirectCallee();
+      else
+        pushforwardFD = m_Builder.HandleNestedDiffRequest(pushforwardFnRequest);
+    } else
+      // Request the derivative
+      pushforwardFD = FindDerivedFunction(pushforwardFnRequest);
     if (pushforwardFD) {
-      if (baseDiff.getExpr()) {
-        callDiff =
-            BuildCallExprToMemFn(baseDiff.getExpr(), pushforwardFD->getName(),
-                                 pushforwardFnArgs, CE->getBeginLoc());
-      } else {
-        Expr* execConfig = nullptr;
-        if (auto KCE = dyn_cast<CUDAKernelCallExpr>(CE))
-          execConfig = Clone(KCE->getConfig());
-        callDiff = m_Sema
-                       .ActOnCallExpr(getCurrentScope(),
-                                      BuildDeclRef(pushforwardFD), validLoc,
-                                      pushforwardFnArgs, validLoc, execConfig)
-                       .get();
-      }
+      if (Expr* baseE = baseDiff.getExpr())
+        pushforwardFnArgs.insert(pushforwardFnArgs.begin(), baseE);
+      callDiff = BuildCallExprToFunction(pushforwardFD, pushforwardFnArgs,
+                                         CUDAExecConfig);
     }
   }
 
@@ -1246,7 +1189,8 @@ StmtDiff BaseForwardModeVisitor::VisitCallExpr(const CallExpr* CE) {
     Expr* call =
         m_Sema
             .ActOnCallExpr(getCurrentScope(), Clone(CE->getCallee()), validLoc,
-                           llvm::MutableArrayRef<Expr*>(CallArgs), validLoc)
+                           llvm::MutableArrayRef<Expr*>(CallArgs), validLoc,
+                           CUDAExecConfig)
             .get();
     // FIXME: Extend this for multiarg support
     // Check if the function is eligible for numerical differentiation.
@@ -1290,13 +1234,16 @@ StmtDiff BaseForwardModeVisitor::VisitUnaryOperator(const UnaryOperator* UnOp) {
   else if (opKind == UO_PostInc || opKind == UO_PostDec ||
            opKind == UO_PreInc || opKind == UO_PreDec) {
     Expr* derivedOp = diff.getExpr_dx();
-    if (diff.getExpr_dx()->getType()->isPointerType())
+    if (derivedOp && diff.getExpr_dx()->getType()->isPointerType())
       derivedOp = BuildOp(opKind, diff.getExpr_dx());
     return StmtDiff(op, derivedOp);
   } /* For supporting complex types */
   else if (opKind == UnaryOperatorKind::UO_Real ||
            opKind == UnaryOperatorKind::UO_Imag) {
-    return StmtDiff(op, BuildOp(opKind, diff.getExpr_dx()));
+    Expr* derivedOp = diff.getExpr_dx();
+    if (derivedOp)
+      derivedOp = BuildOp(opKind, diff.getExpr_dx());
+    return StmtDiff(op, derivedOp);
   } else if (opKind == UnaryOperatorKind::UO_Deref) {
     if (Expr* dx = diff.getExpr_dx())
       return StmtDiff(op, BuildOp(opKind, dx));
@@ -1305,7 +1252,10 @@ StmtDiff BaseForwardModeVisitor::VisitUnaryOperator(const UnaryOperator* UnOp) {
     return StmtDiff(
         op, ConstantFolder::synthesizeLiteral(literalTy, m_Context, /*val=*/0));
   } else if (opKind == UnaryOperatorKind::UO_AddrOf) {
-    return StmtDiff(op, BuildOp(opKind, diff.getExpr_dx()));
+    Expr* derivedOp = diff.getExpr_dx();
+    if (derivedOp)
+      derivedOp = BuildOp(opKind, diff.getExpr_dx());
+    return StmtDiff(op, derivedOp);
   } else if (opKind == UnaryOperatorKind::UO_LNot) {
     Expr* zero = getZeroInit(UnOp->getType());
     if (diff.getExpr_dx() && !isUnusedResult(diff.getExpr_dx()))
@@ -1317,7 +1267,7 @@ StmtDiff BaseForwardModeVisitor::VisitUnaryOperator(const UnaryOperator* UnOp) {
     Expr* derivedOp = BuildOp(UO_Minus, diff.getExpr_dx());
     return {op, derivedOp};
   } else {
-    unsupportedOpWarn(UnOp->getEndLoc());
+    unsupportedOpWarn(UnOp->getOperatorLoc());
     auto zero =
         ConstantFolder::synthesizeLiteral(m_Context.IntTy, m_Context, 0);
     return StmtDiff(op, zero);
@@ -1378,7 +1328,8 @@ BaseForwardModeVisitor::VisitBinaryOperator(const BinaryOperator* BinOp) {
       derivedR = BuildParens(derivedR);
     opDiff = BuildOp(opCode, derivedL, derivedR);
   } else if (BinOp->isAssignmentOp()) {
-    if ((Ldiff.getExpr_dx()->isModifiableLvalue(m_Context) !=
+    if (Ldiff.getExpr_dx() &&
+        (Ldiff.getExpr_dx()->isModifiableLvalue(m_Context) !=
          Expr::MLV_Valid) &&
         !isCladArrayType(Ldiff.getExpr_dx()->getType())) {
       diag(DiagnosticsEngine::Warning, BinOp->getEndLoc(),
@@ -1459,7 +1410,7 @@ BaseForwardModeVisitor::VisitBinaryOperator(const BinaryOperator* BinOp) {
     opDiff = BuildOp(opCode, Ldiff.getExpr_dx(), Rdiff.getExpr());
   } else {
     // FIXME: add support for other binary operators
-    unsupportedOpWarn(BinOp->getEndLoc());
+    unsupportedOpWarn(BinOp->getOperatorLoc());
     opDiff = ConstantFolder::synthesizeLiteral(m_Context.IntTy, m_Context, 0);
   }
   if (opDiff)
@@ -1505,9 +1456,13 @@ BaseForwardModeVisitor::DifferentiateVarDecl(const VarDecl* VD,
         new (m_Context) CXXNullPtrLiteralExpr(VD->getType(), VD->getBeginLoc());
     // NOLINTEND(cppcoreguidelines-owned-memory)
   }
-  VarDecl* VDDerived = BuildVarDecl(
-      VD->getType(), "_d_" + VD->getNameAsString(), initDx, VD->isDirectInit());
-  m_Variables.emplace(VDClone, BuildDeclRef(VDDerived));
+  VarDecl* VDDerived = nullptr;
+  if (m_DiffReq.shouldHaveAdjointForw(VD))
+    VDDerived = BuildVarDecl(VD->getType(), "_d_" + VD->getNameAsString(),
+                             initDx, VD->isDirectInit());
+
+  if (VDDerived)
+    m_Variables.emplace(VDClone, BuildDeclRef(VDDerived));
   return DeclDiff<VarDecl>(VDClone, VDDerived);
 }
 
@@ -1574,7 +1529,8 @@ StmtDiff BaseForwardModeVisitor::VisitDeclStmt(const DeclStmt* DS) {
       if (VDDiff.getDecl()->getDeclName() != VD->getDeclName())
         m_DeclReplacements[VD] = VDDiff.getDecl();
       decls.push_back(VDDiff.getDecl());
-      declsDiff.push_back(VDDiff.getDecl_dx());
+      if (VDDiff.getDecl_dx())
+        declsDiff.push_back(VDDiff.getDecl_dx());
     } else if (auto* SAD = dyn_cast<StaticAssertDecl>(D)) {
       DeclDiff<StaticAssertDecl> SADDiff = DifferentiateStaticAssertDecl(SAD);
       if (SADDiff.getDecl())
@@ -1604,28 +1560,21 @@ BaseForwardModeVisitor::VisitImplicitCastExpr(const ImplicitCastExpr* ICE) {
   return StmtDiff(subExprDiff.getExpr(), subExprDiff.getExpr_dx());
 }
 
-StmtDiff BaseForwardModeVisitor::VisitImplicitValueInitExpr(
-    const ImplicitValueInitExpr* E) {
-  return StmtDiff(Clone(E), Clone(E));
-}
-
-StmtDiff
-BaseForwardModeVisitor::VisitCXXConstCastExpr(const CXXConstCastExpr* CCE) {
-  StmtDiff subExprDiff = Visit(CCE->getSubExpr());
-  Expr* castExpr =
-      m_Sema
-          .BuildCXXNamedCast(CCE->getBeginLoc(), tok::kw_const_cast,
-                             CCE->getTypeInfoAsWritten(), subExprDiff.getExpr(),
-                             CCE->getAngleBrackets(), CCE->getSourceRange())
-          .get();
-  Expr* castExprDiff =
-      m_Sema
-          .BuildCXXNamedCast(CCE->getBeginLoc(), tok::kw_const_cast,
-                             CCE->getTypeInfoAsWritten(),
-                             subExprDiff.getExpr_dx(), CCE->getAngleBrackets(),
-                             CCE->getSourceRange())
-          .get();
-  return StmtDiff(castExpr, castExprDiff);
+StmtDiff BaseForwardModeVisitor::VisitCXXFunctionalCastExpr(
+    const clang::CXXFunctionalCastExpr* FCE) {
+  StmtDiff castExprDiff = Visit(FCE->getSubExpr());
+  SourceLocation fakeLoc = utils::GetValidSLoc(m_Sema);
+  Expr* clonedFCE = m_Sema
+                        .BuildCXXFunctionalCastExpr(
+                            FCE->getTypeInfoAsWritten(), FCE->getType(),
+                            fakeLoc, castExprDiff.getExpr(), fakeLoc)
+                        .get();
+  Expr* derivedFCE = m_Sema
+                         .BuildCXXFunctionalCastExpr(
+                             FCE->getTypeInfoAsWritten(), FCE->getType(),
+                             fakeLoc, castExprDiff.getExpr_dx(), fakeLoc)
+                         .get();
+  return {clonedFCE, derivedFCE};
 }
 
 StmtDiff
@@ -1647,6 +1596,53 @@ BaseForwardModeVisitor::VisitCStyleCastExpr(const CStyleCastExpr* CSCE) {
   return StmtDiff(castExpr, castExprDiff);
 }
 
+StmtDiff
+BaseForwardModeVisitor::VisitCXXNamedCastExpr(const CXXNamedCastExpr* NCE) {
+  StmtDiff subExprDiff = Visit(NCE->getSubExpr());
+  tok::TokenKind CastKind = (tok::TokenKind)~0U;
+  switch (NCE->getStmtClass()) {
+  case Expr::CXXAddrspaceCastExprClass:
+    CastKind = tok::kw_addrspace_cast;
+    break;
+  case Expr::CXXConstCastExprClass:
+    CastKind = tok::kw_const_cast;
+    break;
+  case Expr::CXXDynamicCastExprClass:
+    CastKind = tok::kw_dynamic_cast;
+    break;
+  case Expr::CXXReinterpretCastExprClass:
+    CastKind = tok::kw_reinterpret_cast;
+    break;
+  case Expr::CXXStaticCastExprClass:
+    CastKind = tok::kw_static_cast;
+    break;
+  default:
+    assert(0 && "Unsupported cast kind!");
+    break;
+  }
+
+  SourceLocation Loc = NCE->getBeginLoc();
+  TypeSourceInfo* TSI = NCE->getTypeInfoAsWritten();
+  SourceRange Brackets = NCE->getAngleBrackets();
+  SourceRange Range = NCE->getSourceRange();
+  Expr* castExpr =
+      m_Sema
+          .BuildCXXNamedCast(Loc, CastKind, TSI, subExprDiff.getExpr(),
+                             Brackets, Range)
+          .get();
+  Expr* castExprDiff =
+      m_Sema
+          .BuildCXXNamedCast(Loc, CastKind, TSI, subExprDiff.getExpr_dx(),
+                             Brackets, Range)
+          .get();
+  return StmtDiff(castExpr, castExprDiff);
+}
+
+StmtDiff BaseForwardModeVisitor::VisitImplicitValueInitExpr(
+    const ImplicitValueInitExpr* E) {
+  return StmtDiff(Clone(E), Clone(E));
+}
+
 StmtDiff
 BaseForwardModeVisitor::VisitCXXDefaultArgExpr(const CXXDefaultArgExpr* DE) {
   // FIXME: Shouldn't we simply clone the CXXDefaultArgExpr?
@@ -1747,7 +1743,10 @@ StmtDiff BaseForwardModeVisitor::VisitWhileStmt(const WhileStmt* WS) {
   }
 
   Stmt* WSDiff =
-      clad_compat::Sema_ActOnWhileStmt(m_Sema, condRes, bodyResult).get();
+      m_Sema
+          .ActOnWhileStmt(/*WhileLoc=*/noLoc, /*LParenLoc=*/noLoc, condRes,
+                          /*RParenLoc=*/noLoc, bodyResult)
+          .get();
   // end scope for while loop
   endScope();
   return StmtDiff(WSDiff);
@@ -2053,7 +2052,7 @@ StmtDiff BaseForwardModeVisitor::VisitMaterializeTemporaryExpr(
     const clang::MaterializeTemporaryExpr* MTE) {
   // `MaterializeTemporaryExpr` node will be created automatically if it is
   // required by `ActOn`/`Build` Sema functions.
-  StmtDiff MTEDiff = Visit(clad_compat::GetSubExpr(MTE));
+  StmtDiff MTEDiff = Visit(MTE->getSubExpr());
   return MTEDiff;
 }
 
@@ -2135,41 +2134,6 @@ BaseForwardModeVisitor::VisitCXXDeleteExpr(const clang::CXXDeleteExpr* CDE) {
   return {clonedDeleteE, derivedDeleteE};
 }
 
-StmtDiff BaseForwardModeVisitor::VisitCXXStaticCastExpr(
-    const clang::CXXStaticCastExpr* CSE) {
-  auto diff = Visit(CSE->getSubExpr());
-  Expr* clonedE =
-      m_Sema
-          .BuildCXXNamedCast(noLoc, tok::TokenKind::kw_static_cast,
-                             CSE->getTypeInfoAsWritten(), diff.getExpr(),
-                             SourceRange(), SourceRange())
-          .get();
-  Expr* derivedE =
-      m_Sema
-          .BuildCXXNamedCast(noLoc, tok::TokenKind::kw_static_cast,
-                             CSE->getTypeInfoAsWritten(), diff.getExpr_dx(),
-                             SourceRange(), SourceRange())
-          .get();
-  return {clonedE, derivedE};
-}
-
-StmtDiff BaseForwardModeVisitor::VisitCXXFunctionalCastExpr(
-    const clang::CXXFunctionalCastExpr* FCE) {
-  StmtDiff castExprDiff = Visit(FCE->getSubExpr());
-  SourceLocation fakeLoc = utils::GetValidSLoc(m_Sema);
-  Expr* clonedFCE = m_Sema
-                        .BuildCXXFunctionalCastExpr(
-                            FCE->getTypeInfoAsWritten(), FCE->getType(),
-                            fakeLoc, castExprDiff.getExpr(), fakeLoc)
-                        .get();
-  Expr* derivedFCE = m_Sema
-                         .BuildCXXFunctionalCastExpr(
-                             FCE->getTypeInfoAsWritten(), FCE->getType(),
-                             fakeLoc, castExprDiff.getExpr_dx(), fakeLoc)
-                         .get();
-  return {clonedFCE, derivedFCE};
-}
-
 StmtDiff BaseForwardModeVisitor::VisitCXXBindTemporaryExpr(
     const clang::CXXBindTemporaryExpr* BTE) {
   // `CXXBindTemporaryExpr` node will be created automatically, if it is
@@ -2220,17 +2184,10 @@ clang::Expr* BaseForwardModeVisitor::BuildCustomDerivativeConstructorPFCall(
     llvm::SmallVectorImpl<clang::Expr*>& clonedArgs,
     llvm::SmallVectorImpl<clang::Expr*>& derivedArgs) {
   llvm::SmallVector<Expr*, 4> customPushforwardArgs;
-  QualType constructorPushforwardTagT = GetCladConstructorPushforwardTagOfType(
-      CE->getType().withoutLocalFastQualifiers());
-  // Builds clad::ConstructorPushforwardTag<T> declaration
-  Expr* constructorPushforwardTagArg =
-      m_Sema
-          .BuildCXXTypeConstructExpr(
-              m_Context.getTrivialTypeSourceInfo(constructorPushforwardTagT,
-                                                 utils::GetValidSLoc(m_Sema)),
-              noLoc, MultiExprArg{}, noLoc, /*ListInitialization=*/false)
-          .get();
-  customPushforwardArgs.push_back(constructorPushforwardTagArg);
+  // Builds clad::Tag<T>()
+  Expr* tagArg =
+      utils::GetCladTagExpr(m_Sema, CE->getType().withoutLocalFastQualifiers());
+  customPushforwardArgs.push_back(tagArg);
   customPushforwardArgs.append(clonedArgs.begin(), clonedArgs.end());
   customPushforwardArgs.append(derivedArgs.begin(), derivedArgs.end());
   std::string customPushforwardName =
@@ -2240,4 +2197,4 @@ clang::Expr* BaseForwardModeVisitor::BuildCustomDerivativeConstructorPFCall(
       customPushforwardName, customPushforwardArgs, getCurrentScope(), CE);
   return pushforwardCall;
 }
-} // end namespace clad
+} // end namespace clad
\ No newline at end of file
