@@ -7,38 +7,52 @@
 #include "ClangPlugin.h"
 
 #include "clad/Differentiator/DerivativeBuilder.h"
+#include "clad/Differentiator/DiffPlanner.h"
 #include "clad/Differentiator/EstimationModel.h"
-
 #include "clad/Differentiator/Sins.h"
+#include "clad/Differentiator/Timers.h"
 #include "clad/Differentiator/Version.h"
+#include "../lib/Differentiator/TBRAnalyzer.h"
 
 #include "clang/AST/ASTConsumer.h"
 #include "clang/AST/ASTContext.h"
 #include "clang/AST/Attr.h"
 #include "clang/AST/RecursiveASTVisitor.h"
+#include "clang/Basic/LLVM.h" // isa, dyn_cast
+#include "clang/Basic/SourceLocation.h"
 #include "clang/Basic/Version.h"
 #include "clang/Frontend/CompilerInstance.h"
 #include "clang/Frontend/FrontendPluginRegistry.h"
 #include "clang/Frontend/MultiplexConsumer.h"
 #include "clang/Lex/LexDiagnostic.h"
-#include "clang/Sema/Sema.h"
 #include "clang/Sema/Lookup.h"
+#include "clang/Sema/Sema.h"
 
+#include "llvm/ADT/STLExtras.h"
 #include "llvm/Support/Timer.h"
 #include "llvm/Support/raw_ostream.h"
 
+#include "clad/Differentiator/CladUtils.h"
 #include "clad/Differentiator/Compatibility.h"
+#include "clad/Differentiator/DiffMode.h"
 
 #include <algorithm>
+#include <cassert>
+#include <cstdlib>  // for getenv
 #include <iostream> // for std::cerr
+#include <memory>
+#include <set>
 
 using namespace clang;
 
 namespace clad {
+void InitTimers();
+
   namespace plugin {
     /// Keeps track if we encountered #pragma clad on/off.
     // FIXME: Figure out how to make it a member of CladPlugin.
     std::vector<clang::SourceRange> CladEnabledRange;
+    std::set<clang::SourceLocation> CladLoopCheckpoints;
 
     // Define a pragma handler for #pragma clad
     class CladPragmaHandler : public PragmaHandler {
@@ -46,7 +60,6 @@ namespace clad {
       CladPragmaHandler() : PragmaHandler("clad") {}
       void HandlePragma(Preprocessor& PP, PragmaIntroducer Introducer,
                         Token& PragmaTok) override {
-        // Handle #pragma clad ON/OFF/DEFAULT
         if (PragmaTok.isNot(tok::identifier)) {
           PP.Diag(PragmaTok, diag::warn_pragma_diagnostic_invalid);
           return;
@@ -56,25 +69,61 @@ namespace clad {
         assert(II->isStr("clad"));
 #endif
 
-        tok::OnOffSwitch OOS;
-        if (PP.LexOnOffSwitch(OOS))
-          return; // failure
+        PP.Lex(PragmaTok);
+        llvm::StringRef OptionName = PragmaTok.getIdentifierInfo()->getName();
         SourceLocation TokLoc = PragmaTok.getLocation();
-        if (OOS == tok::OOS_ON) {
+        // Handle #pragma clad ON
+        if (OptionName == "ON") {
           SourceRange R(TokLoc, /*end*/ SourceLocation());
           // If a second ON is seen, ignore it if the interval is open.
           if (CladEnabledRange.empty() ||
               CladEnabledRange.back().getEnd().isValid())
             CladEnabledRange.push_back(R);
-        } else if (!CladEnabledRange.empty()) { // OOS_OFF or OOS_DEFAULT
-          assert(CladEnabledRange.back().getEnd().isInvalid());
-          CladEnabledRange.back().setEnd(TokLoc);
+          return;
         }
+        // Handle #pragma clad OFF/DEFAULT
+        if (OptionName == "OFF" || OptionName == "DEFAULT") {
+          if (!CladEnabledRange.empty()) {
+            assert(CladEnabledRange.back().getEnd().isInvalid());
+            CladEnabledRange.back().setEnd(TokLoc);
+          }
+          return;
+        }
+        // Handle #pragma clad checkpoint loop
+        if (OptionName == "checkpoint") {
+          PP.Lex(PragmaTok);
+          // Ensure the next token is `loop`
+          if (PragmaTok.isNot(tok::identifier) ||
+              PragmaTok.getIdentifierInfo()->getName() != "loop") {
+            PP.Diag(PragmaTok.getLocation(),
+                    PP.getDiagnostics().getCustomDiagID(
+                        DiagnosticsEngine::Error,
+                        "expected 'loop' after 'checkpoint' in #pragma clad"));
+            return;
+          }
+          CladLoopCheckpoints.insert(PragmaTok.getLocation());
+          return;
+        }
+        // Diagnose unknown clad pragma option
+        PP.Diag(
+            TokLoc,
+            PP.getDiagnostics().getCustomDiagID(
+                DiagnosticsEngine::Error,
+                "expected 'ON', 'OFF', 'DEFAULT', or `checkpoint` in pragma"));
       }
     };
 
     CladPlugin::CladPlugin(CompilerInstance& CI, DifferentiationOptions& DO)
         : m_CI(CI), m_DO(DO), m_HasRuntime(false) {
+#if CLANG_VERSION_MAJOR > 11
+      bool WantTiming = m_CI.getCodeGenOpts().TimePasses;
+#else
+      bool WantTiming = m_CI.getFrontendOpts().ShowTimers;
+#endif
+
+      if (WantTiming || getenv("CLAD_ENABLE_TIMING"))
+        InitTimers();
+
       FrontendOptions& Opts = CI.getFrontendOpts();
       // Find the path to clad.
       llvm::StringRef CladSoPath;
@@ -125,19 +174,26 @@ namespace clad {
     void CladPlugin::HandleTopLevelDeclForClad(DeclGroupRef DGR) {
       if (!CheckBuiltins())
         return;
-
+#if CLANG_VERSION_MAJOR > 16
       Sema& S = m_CI.getSema();
-
-      if (!m_DerivativeBuilder)
-        m_DerivativeBuilder.reset(
-            new DerivativeBuilder(S, *this, m_DFC, m_DiffRequestGraph));
-
       RequestOptions opts{};
       SetRequestOptions(opts);
-      DiffCollector collector(DGR, CladEnabledRange, m_DiffRequestGraph, S,
-                              opts);
+      // Traverse all constexpr FunctionDecls for the static graph only once to
+      // differentiate them immeditely.
+      {
+        TimedAnalysisRegion R("Rest of constexpr TU");
+        for (Decl* D : DGR) {
+          if (!isa<FunctionDecl>(D))
+            continue;
+          auto* FD = cast<FunctionDecl>(D);
+          if (FD->isConstexpr() || !m_Multiplexer) {
+            DiffCollector collector(DGR, CladEnabledRange, m_DiffRequestGraph,
+                                    S, opts, m_AllAnalysisDC);
+            break;
+          }
+        }
+      }
 
-#if CLANG_VERSION_MAJOR > 16
       for (DiffRequest& request : m_DiffRequestGraph.getNodes()) {
         if (request.ImmediateMode && request.Function->isConstexpr()) {
           m_DiffRequestGraph.setCurrentProcessingNode(request);
@@ -147,21 +203,88 @@ namespace clad {
       }
 #endif
 
-      // We could not delay the processing of derivatives, inform act as if each
+      // We could not delay the processing of derivatives, act as if each
       // call is final. That would still have vgvassilev/clad#248 unresolved.
-      if (!m_Multiplexer)
+      if (!m_Multiplexer && !m_CI.getDiagnostics().hasErrorOccurred())
         FinalizeTranslationUnit();
     }
 
+    static void printDerivative(clang::Decl* D, bool DeclarationOnly,
+                                const DifferentiationOptions& DO) {
+      clang::LangOptions LangOpts;
+      LangOpts.CPlusPlus = true;
+      clang::PrintingPolicy Policy(LangOpts);
+      Policy.Bool = true;
+
+      // if enabled, print source code of the derivatives
+      if (DO.DumpDerivedFn) {
+        D->print(llvm::outs(), Policy);
+        if (DeclarationOnly)
+          llvm::outs() << ";\n";
+      }
+
+      // if enabled, print ASTs of the derivatives
+      if (DO.DumpDerivedAST)
+        D->dumpColor();
+
+      // if enabled, print the derivatives in a file
+      if (DO.GenerateSourceFile) {
+        std::error_code err;
+        llvm::raw_fd_ostream f("Derivatives.cpp", err,
+                               CLAD_COMPAT_llvm_sys_fs_Append);
+        D->print(f, Policy);
+        if (DeclarationOnly)
+          f << ";\n";
+        f.flush();
+      }
+    }
+
+    static void addCladLoopCheckpoints(ASTContext& C, DiffRequest& request) {
+      SourceRange range = request->getSourceRange();
+      assert(range.isValid());
+      SourceLocation begin = range.getBegin();
+      SourceLocation end = range.getEnd();
+      clang::SourceManager& SM = C.getSourceManager();
+      auto it = CladLoopCheckpoints.upper_bound(begin);
+      auto e = CladLoopCheckpoints.end();
+
+      for (; it != e && SM.isBeforeInTranslationUnit(*it, end); ++it)
+        request.m_CladLoopCheckpoints.emplace(*it, false);
+    }
+
+    static void diagnoseUnusedPragma(Sema& S, DiffRequest& request) {
+      for (const auto& pair : request.m_CladLoopCheckpoints) {
+        if (!pair.second) {
+          unsigned diagID = S.Diags.getCustomDiagID(
+              DiagnosticsEngine::Error,
+              "'#pragma clad checkpoint loop' is only allowed before a loop");
+          S.Diag(pair.first, diagID);
+        }
+      }
+    }
+
     FunctionDecl* CladPlugin::ProcessDiffRequest(DiffRequest& request) {
       Sema& S = m_CI.getSema();
-      // Required due to custom derivatives function templates that might be
-      // used in the function that we need to derive.
-      // FIXME: Remove the call to PerformPendingInstantiations().
-      S.PerformPendingInstantiations();
+      if (!m_DerivativeBuilder)
+        m_DerivativeBuilder = std::make_unique<DerivativeBuilder>(
+            S, *this, m_DFC, m_DiffRequestGraph);
+
+      if (request.Global) {
+        auto deriveResult = m_DerivativeBuilder->Derive(request);
+        auto* VDDiff = cast_or_null<VarDecl>(deriveResult.derivative);
+        ProcessTopLevelDecl(VDDiff);
+        // Dump the declaration if requested.
+        printDerivative(VDDiff, request.DeclarationOnly, m_DO);
+        return nullptr;
+      }
+
       if (request.Function->getDefinition())
         request.Function = request.Function->getDefinition();
-      request.UpdateDiffParamsInfo(m_CI.getSema());
+      // FIXME: These requests are not fully generated in the diffplanner and we
+      // have to update diff params on this stage.
+      if (request.CurrentDerivativeOrder > 1 ||
+          m_DFC.IsCladDerivative(request.Function))
+        request.UpdateDiffParamsInfo(m_CI.getSema());
       const FunctionDecl* FD = request.Function;
       ASTContext& C = S.getASTContext();
       clang::PrintingPolicy Policy = C.getPrintingPolicy();
@@ -204,72 +327,52 @@ namespace clad {
         m_DerivativeBuilder->setNumDiffErrDiag(true);
       }
 
+      // Propagate relevant pragmas to diffrequests
+      addCladLoopCheckpoints(C, request);
+
       FunctionDecl* DerivativeDecl = nullptr;
       bool alreadyDerived = false;
       FunctionDecl* OverloadedDerivativeDecl = nullptr;
       {
-        // FIXME: Move the timing inside the DerivativeBuilder. This would
-        // require to pass in the DifferentiationOptions in the DiffPlan.
-        // derive the collected functions
-
-#if CLANG_VERSION_MAJOR > 11
-        bool WantTiming = m_CI.getCodeGenOpts().TimePasses;
-#else
-        bool WantTiming = m_CI.getFrontendOpts().ShowTimers;
-#endif
-
+        llvm::SaveAndRestore<unsigned> Saved(request.RequestedDerivativeOrder,
+                                             1);
         auto DFI = m_DFC.Find(request);
         if (DFI.IsValid()) {
           DerivativeDecl = DFI.DerivedFn();
           OverloadedDerivativeDecl = DFI.OverloadedDerivedFn();
           alreadyDerived = true;
         } else {
-          // Only time the function when it is first encountered
-          if (WantTiming)
-            m_CTG.StartNewTimer("Timer for clad func",
-                                request.BaseFunctionName);
-
           auto deriveResult = m_DerivativeBuilder->Derive(request);
-          DerivativeDecl = deriveResult.derivative;
+          DerivativeDecl = cast_or_null<FunctionDecl>(deriveResult.derivative);
           OverloadedDerivativeDecl = deriveResult.overload;
-          if (WantTiming)
-            m_CTG.StopTimer();
+          // FIXME: Doing this with other function types might lead to
+          // accidental numerical diff.
+          if (isa<CXXConstructorDecl>(FD) &&
+              (request.Mode == DiffMode::pullback) &&
+              utils::hasEmptyBody(DerivativeDecl))
+            return nullptr;
+          if (DerivativeDecl)
+            m_DFC.Add(DerivedFnInfo(request, DerivativeDecl,
+                                    OverloadedDerivativeDecl));
         }
       }
 
+      // Propagate relevant pragmas to diffrequests
+      diagnoseUnusedPragma(S, request);
+
+      if (OverloadedDerivativeDecl) {
+        S.MarkFunctionReferenced(SourceLocation(), OverloadedDerivativeDecl);
+        DelayedCallInfo DCI{CallKind::HandleTopLevelDecl,
+                            OverloadedDerivativeDecl};
+        if (!llvm::is_contained(m_DelayedCalls, DCI))
+          ProcessTopLevelDecl(OverloadedDerivativeDecl);
+      }
       if (DerivativeDecl) {
-        if (!alreadyDerived) {
-          m_DFC.Add(
-              DerivedFnInfo(request, DerivativeDecl, OverloadedDerivativeDecl));
-
-          // if enabled, print source code of the derived functions
-          if (m_DO.DumpDerivedFn) {
-            DerivativeDecl->print(llvm::outs(), Policy);
-            if (request.DeclarationOnly)
-              llvm::outs() << ";\n";
-          }
-
-          // if enabled, print ASTs of the derived functions
-          if (m_DO.DumpDerivedAST) {
-            DerivativeDecl->dumpColor();
-          }
-
-          // if enabled, print the derivatives in a file.
-          if (m_DO.GenerateSourceFile) {
-            std::error_code err;
-            llvm::raw_fd_ostream f("Derivatives.cpp", err,
-                                   CLAD_COMPAT_llvm_sys_fs_Append);
-            DerivativeDecl->print(f, Policy);
-            if (request.DeclarationOnly)
-              f << ";\n";
-            f.flush();
-          }
+        if (!alreadyDerived &&
+            (!request.CustomDerivative || request.CallUpdateRequired)) {
+          printDerivative(DerivativeDecl, request.DeclarationOnly, m_DO);
 
           S.MarkFunctionReferenced(SourceLocation(), DerivativeDecl);
-          if (OverloadedDerivativeDecl)
-            S.MarkFunctionReferenced(SourceLocation(),
-                                     OverloadedDerivativeDecl);
-
           // We ideally should not call `HandleTopLevelDecl` for declarations
           // inside a namespace. After parsing a namespace that is defined
           // directly in translation unit context , clang calls
@@ -285,13 +388,11 @@ namespace clad {
           // FIXME: We could get rid of this by prepending the produced
           // derivatives in CladPlugin::HandleTranslationUnitDecl
           DeclContext* derivativeDC = DerivativeDecl->getLexicalDeclContext();
+          DelayedCallInfo DCI{CallKind::HandleTopLevelDecl, DerivativeDecl};
           bool isTUorND =
               derivativeDC->isTranslationUnit() || derivativeDC->isNamespace();
-          if (isTUorND) {
+          if (isTUorND && !llvm::is_contained(m_DelayedCalls, DCI))
             ProcessTopLevelDecl(DerivativeDecl);
-            if (OverloadedDerivativeDecl)
-              ProcessTopLevelDecl(OverloadedDerivativeDecl);
-          }
         }
         bool lastDerivativeOrder = (request.CurrentDerivativeOrder ==
                                     request.RequestedDerivativeOrder);
@@ -359,12 +460,10 @@ namespace clad {
           m_Multiplexer->CompleteTentativeDefinition(
               cast<VarDecl>(D.getSingleDecl()));
           break;
-#if CLANG_VERSION_MAJOR > 9
         case CallKind::CompleteExternalDeclaration:
           m_Multiplexer->CompleteExternalDeclaration(
               cast<VarDecl>(D.getSingleDecl()));
           break;
-#endif
         case CallKind::AssignInheritanceModel:
           m_Multiplexer->AssignInheritanceModel(
               cast<CXXRecordDecl>(D.getSingleDecl()));
@@ -410,22 +509,32 @@ namespace clad {
       if (DO.EnableTBRAnalysis || DO.DisableTBRAnalysis)
         opts.EnableTBRAnalysis = DO.EnableTBRAnalysis && !DO.DisableTBRAnalysis;
       else
-        opts.EnableTBRAnalysis = false; // Default mode.
+        opts.EnableTBRAnalysis = true; // Default mode.
     }
 
     static void SetActivityAnalysisOptions(const DifferentiationOptions& DO,
                                            RequestOptions& opts) {
       // If user has explicitly specified the mode for AA, use it.
-      if (DO.EnableVariedAnalysis || DO.DisableActivityAnalysis)
+      if (DO.EnableVariedAnalysis || DO.DisableVariedAnalysis)
         opts.EnableVariedAnalysis =
-            DO.EnableVariedAnalysis && !DO.DisableActivityAnalysis;
+            DO.EnableVariedAnalysis && !DO.DisableVariedAnalysis;
       else
         opts.EnableVariedAnalysis = false; // Default mode.
     }
 
+    static void SetUsefulAnalysisOptions(const DifferentiationOptions& DO,
+                                         RequestOptions& opts) {
+      // If user has explicitly specified the mode for TBR analysis, use it.
+      if (DO.EnableUsefulAnalysis || DO.DisableUsefulAnalysis)
+        opts.EnableUsefulAnalysis =
+            DO.EnableUsefulAnalysis && !DO.DisableUsefulAnalysis;
+      else
+        opts.EnableUsefulAnalysis = false; // Default mode.
+    }
     void CladPlugin::SetRequestOptions(RequestOptions& opts) const {
       SetTBRAnalysisOptions(m_DO, opts);
       SetActivityAnalysisOptions(m_DO, opts);
+      SetUsefulAnalysisOptions(m_DO, opts);
     }
 
     void CladPlugin::FinalizeTranslationUnit() {
@@ -434,15 +543,17 @@ namespace clad {
       if (!m_CI.getPreprocessor().isIncrementalProcessingEnabled())
         S.TUScope = m_StoredTUScope;
       constexpr bool Enabled = true;
-      Sema::GlobalEagerInstantiationScope GlobalInstantiations(S, Enabled);
-      Sema::LocalEagerInstantiationScope LocalInstantiations(S);
+      Sema::GlobalEagerInstantiationScope GlobalInstantiations(
+          S, Enabled CLAD_COMPAT_CLANG21_AtEndOfTUParam);
+      Sema::LocalEagerInstantiationScope LocalInstantiations(
+          S CLAD_COMPAT_CLANG21_AtEndOfTUParam);
 
       if (!m_DiffRequestGraph.isProcessingNode()) {
         // This check is to avoid recursive processing of the graph, as
         // HandleTopLevelDecl can be called recursively in non-standard
         // setup for code generation.
         DiffRequest request = m_DiffRequestGraph.getNextToProcessNode();
-        while (request.Function) {
+        while (request.Function || request.Global) {
           m_DiffRequestGraph.setCurrentProcessingNode(request);
           ProcessDiffRequest(request);
           m_DiffRequestGraph.markCurrentNodeProcessed();
@@ -460,8 +571,34 @@ namespace clad {
     }
 
     void CladPlugin::HandleTranslationUnit(ASTContext& C) {
-      FinalizeTranslationUnit();
-      SendToMultiplexer();
+      // In case of diagnostics, don't bother, just let the compiler finish.
+      if (!m_CI.getDiagnostics().hasErrorOccurred()) {
+        Sema& S = m_CI.getSema();
+        RequestOptions opts{};
+        SetRequestOptions(opts);
+        // Traverse all collected DeclGroupRef only once to create the static
+        // graph.
+        TimedAnalysisRegion R("Rest of TU");
+        for (auto DCI : m_DelayedCalls)
+          for (Decl* D : DCI.m_DGR) {
+            if (const auto* FD = dyn_cast<FunctionDecl>(D))
+              if (FD->isConstexpr())
+                continue;
+            DiffCollector collector(DCI.m_DGR, CladEnabledRange,
+                                    m_DiffRequestGraph, S, opts,
+                                    m_AllAnalysisDC);
+            break;
+          }
+
+        if (m_CI.getFrontendOpts().ShowStats) {
+          // Print the graph of the diff requests.
+          llvm::errs() << "\n*** INFORMATION ABOUT THE DIFF REQUESTS\n";
+          m_DiffRequestGraph.dump();
+        }
+
+        FinalizeTranslationUnit();
+        SendToMultiplexer();
+      }
       m_Multiplexer->HandleTranslationUnit(C);
     }
 
@@ -500,11 +637,9 @@ namespace clad {
         case CallKind::CompleteTentativeDefinition:
           llvm::errs() << "CompleteTentativeDefinition";
           break;
-#if CLANG_VERSION_MAJOR > 9
         case CallKind::CompleteExternalDeclaration:
           llvm::errs() << "CompleteExternalDeclaration";
           break;
-#endif
         case CallKind::AssignInheritanceModel:
           llvm::errs() << "AssignInheritanceModel";
           break;
@@ -523,32 +658,11 @@ namespace clad {
         llvm::errs() << "\n";
       }
 
-      // Print the graph of the diff requests.
-      llvm::errs() << "\n*** INFORMATION ABOUT THE DIFF REQUESTS\n";
-      m_DiffRequestGraph.dump();
-
       m_Multiplexer->PrintStats();
     }
 
   } // end namespace plugin
 
-  clad::CladTimerGroup::CladTimerGroup()
-      : m_Tg("Timers for Clad Funcs", "Timers for Clad Funcs") {}
-
-  void clad::CladTimerGroup::StartNewTimer(llvm::StringRef TimerName,
-                                           llvm::StringRef TimerDesc) {
-      std::unique_ptr<llvm::Timer> tm(
-          new llvm::Timer(TimerName, TimerDesc, m_Tg));
-      m_Timers.push_back(std::move(tm));
-      m_Timers.back()->startTimer();
-  }
-
-  void clad::CladTimerGroup::StopTimer() {
-      m_Timers.back()->stopTimer();
-      if (m_Timers.size() != 1)
-        m_Timers.pop_back();
-  }
-
   // Routine to check clang version at runtime against the clang version for
   // which clad was built.
   bool checkClangVersion() {
