@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -779,23 +779,25 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libUnuran dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-class __attribute__((annotate("$clingAutoload$TUnuranBaseDist.h")))  __attribute__((annotate("$clingAutoload$TUnuran.h")))  TUnuranBaseDist;
-class __attribute__((annotate("$clingAutoload$TUnuran.h")))  TUnuran;
-class __attribute__((annotate("$clingAutoload$TUnuranContDist.h")))  TUnuranContDist;
-class __attribute__((annotate("$clingAutoload$TUnuranDiscrDist.h")))  TUnuranDiscrDist;
-class __attribute__((annotate("$clingAutoload$TUnuranEmpDist.h")))  TUnuranEmpDist;
-class __attribute__((annotate("$clingAutoload$TUnuranMultiContDist.h")))  TUnuranMultiContDist;
-class __attribute__((annotate("$clingAutoload$TUnuranSampler.h")))  TUnuranSampler;
+class  __attribute__((annotate("$clingAutoload$TUnuranBaseDist.h")))  __attribute__((annotate("$clingAutoload$TUnuran.h")))  TUnuranBaseDist;
+class  __attribute__((annotate("$clingAutoload$TUnuran.h")))  TUnuran;
+class  __attribute__((annotate("$clingAutoload$TUnuranContDist.h")))  TUnuranContDist;
+class  __attribute__((annotate("$clingAutoload$TUnuranDiscrDist.h")))  TUnuranDiscrDist;
+class  __attribute__((annotate("$clingAutoload$TUnuranEmpDist.h")))  TUnuranEmpDist;
+class  __attribute__((annotate("$clingAutoload$TUnuranMultiContDist.h")))  TUnuranMultiContDist;
+class  __attribute__((annotate("$clingAutoload$TUnuranSampler.h")))  TUnuranSampler;
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libUnuran dictionary payload"
@@ -803,6 +805,9 @@ class __attribute__((annotate("$clingAutoload$TUnuranSampler.h")))  TUnuranSampl
 #ifndef ROOT_SUPPORT_CLAD
   #define ROOT_SUPPORT_CLAD 1
 #endif
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
