@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -959,27 +959,27 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include/freetype2",
-"/usr/include",
-"/usr/include/freetype2",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libEG dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-class __attribute__((annotate("$clingAutoload$TAttParticle.h")))  TAttParticle;
-class __attribute__((annotate("$clingAutoload$TParticlePDG.h")))  __attribute__((annotate("$clingAutoload$TDatabasePDG.h")))  TParticlePDG;
-class __attribute__((annotate("$clingAutoload$TParticleClassPDG.h")))  __attribute__((annotate("$clingAutoload$TDatabasePDG.h")))  TParticleClassPDG;
-class __attribute__((annotate("$clingAutoload$TDatabasePDG.h")))  TDatabasePDG;
-class __attribute__((annotate("$clingAutoload$TDecayChannel.h")))  TDecayChannel;
-class __attribute__((annotate("$clingAutoload$TGenerator.h")))  TGenerator;
-class __attribute__((annotate("$clingAutoload$TParticle.h")))  TParticle;
-class __attribute__((annotate("$clingAutoload$TPrimary.h")))  TPrimary;
-class __attribute__((annotate("$clingAutoload$TVirtualMCDecayer.h")))  TVirtualMCDecayer;
+class  __attribute__((annotate("$clingAutoload$TAttParticle.h")))  TAttParticle;
+class  __attribute__((annotate("$clingAutoload$TParticlePDG.h")))  __attribute__((annotate("$clingAutoload$TDatabasePDG.h")))  TParticlePDG;
+class  __attribute__((annotate("$clingAutoload$TParticleClassPDG.h")))  __attribute__((annotate("$clingAutoload$TDatabasePDG.h")))  TParticleClassPDG;
+class  __attribute__((annotate("$clingAutoload$TDatabasePDG.h")))  TDatabasePDG;
+class  __attribute__((annotate("$clingAutoload$TDecayChannel.h")))  TDecayChannel;
+class  __attribute__((annotate("$clingAutoload$TGenerator.h")))  TGenerator;
+class  __attribute__((annotate("$clingAutoload$TParticle.h")))  TParticle;
+class  __attribute__((annotate("$clingAutoload$TPrimary.h")))  TPrimary;
+class  __attribute__((annotate("$clingAutoload$TVirtualMCDecayer.h")))  TVirtualMCDecayer;
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libEG dictionary payload"
@@ -987,6 +987,9 @@ class __attribute__((annotate("$clingAutoload$TVirtualMCDecayer.h")))  TVirtualM
 #ifndef ROOT_SUPPORT_CLAD
   #define ROOT_SUPPORT_CLAD 1
 #endif
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
