@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -58,7 +58,7 @@ namespace ROOT {
       ::TAuthenticate *ptr = nullptr;
       static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TAuthenticate >(nullptr);
       static ::ROOT::TGenericClassInfo 
-         instance("TAuthenticate", ::TAuthenticate::Class_Version(), "TAuthenticate.h", 53,
+         instance("TAuthenticate", ::TAuthenticate::Class_Version(), "TAuthenticate.h", 52,
                   typeid(::TAuthenticate), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                   &::TAuthenticate::Dictionary, isa_proxy, 16,
                   sizeof(::TAuthenticate) );
@@ -485,24 +485,29 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libRootAuth dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-class __attribute__((annotate("$clingAutoload$TAuthenticate.h")))  TAuthenticate;
-class __attribute__((annotate("$clingAutoload$TRootSecContext.h")))  __attribute__((annotate("$clingAutoload$THostAuth.h")))  TRootSecContext;
-class __attribute__((annotate("$clingAutoload$THostAuth.h")))  THostAuth;
-class __attribute__((annotate("$clingAutoload$TRootAuth.h")))  TRootAuth;
+class  __attribute__((annotate("$clingAutoload$TAuthenticate.h")))  TAuthenticate;
+class  __attribute__((annotate("$clingAutoload$TRootSecContext.h")))  __attribute__((annotate("$clingAutoload$THostAuth.h")))  TRootSecContext;
+class  __attribute__((annotate("$clingAutoload$THostAuth.h")))  THostAuth;
+class  __attribute__((annotate("$clingAutoload$TRootAuth.h")))  TRootAuth;
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libRootAuth dictionary payload"
 
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
