@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -942,25 +942,27 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libRHTTP dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-class __attribute__((annotate("$clingAutoload$THttpCallArg.h")))  THttpCallArg;
-class __attribute__((annotate("$clingAutoload$THttpEngine.h")))  THttpEngine;
-class __attribute__((annotate("$clingAutoload$THttpServer.h")))  THttpServer;
-class __attribute__((annotate("$clingAutoload$THttpWSHandler.h")))  THttpWSHandler;
-class __attribute__((annotate("$clingAutoload$TRootSniffer.h")))  TRootSnifferScanRec;
-class __attribute__((annotate("$clingAutoload$TRootSniffer.h")))  TRootSniffer;
-class __attribute__((annotate("$clingAutoload$TRootSnifferStore.h")))  TRootSnifferStore;
-class __attribute__((annotate("$clingAutoload$TRootSnifferStore.h")))  TRootSnifferStoreXml;
-class __attribute__((annotate("$clingAutoload$TRootSnifferStore.h")))  TRootSnifferStoreJson;
+class  __attribute__((annotate("$clingAutoload$THttpCallArg.h")))  THttpCallArg;
+class  __attribute__((annotate("$clingAutoload$THttpEngine.h")))  THttpEngine;
+class  __attribute__((annotate("$clingAutoload$THttpServer.h")))  THttpServer;
+class  __attribute__((annotate("$clingAutoload$THttpWSHandler.h")))  THttpWSHandler;
+class  __attribute__((annotate("$clingAutoload$TRootSniffer.h")))  TRootSnifferScanRec;
+class  __attribute__((annotate("$clingAutoload$TRootSniffer.h")))  TRootSniffer;
+class  __attribute__((annotate("$clingAutoload$TRootSnifferStore.h")))  TRootSnifferStore;
+class  __attribute__((annotate("$clingAutoload$TRootSnifferStore.h")))  TRootSnifferStoreXml;
+class  __attribute__((annotate("$clingAutoload$TRootSnifferStore.h")))  TRootSnifferStoreJson;
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libRHTTP dictionary payload"
@@ -977,6 +979,9 @@ class __attribute__((annotate("$clingAutoload$TRootSnifferStore.h")))  TRootSnif
 #ifndef NO_SSL_DL
   #define NO_SSL_DL 1
 #endif
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
