@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -696,26 +696,27 @@ nullptr
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/lib/python3.13/site-packages/numpy/_core/include",
-"/usr/include",
+"/build/root/src/build-cuda/tmva/sofie",
 "/usr/lib/python3.13/site-packages/numpy/_core/include",
 "/usr/include/python3.13",
-"/build/root/src/build-cuda/tmva/sofie",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
     static const char* fwdDeclCode = R"DICTFWDDCLS(
 #line 1 "libPyMVA dictionary forward declarations' payload"
+
+#pragma diagnostic push
 #pragma clang diagnostic ignored "-Wkeyword-compat"
 #pragma clang diagnostic ignored "-Wignored-attributes"
 #pragma clang diagnostic ignored "-Wreturn-type-c-linkage"
 extern int __Cling_AutoLoading_Map;
-namespace TMVA{class __attribute__((annotate("$clingAutoload$TMVA/PyMethodBase.h")))  __attribute__((annotate("$clingAutoload$TMVA/MethodPyAdaBoost.h")))  PyMethodBase;}
-namespace TMVA{class __attribute__((annotate("$clingAutoload$TMVA/MethodPyAdaBoost.h")))  MethodPyAdaBoost;}
-namespace TMVA{class __attribute__((annotate("$clingAutoload$TMVA/MethodPyGTB.h")))  MethodPyGTB;}
-namespace TMVA{class __attribute__((annotate("$clingAutoload$TMVA/MethodPyKeras.h")))  MethodPyKeras;}
-namespace TMVA{class __attribute__((annotate("$clingAutoload$TMVA/MethodPyRandomForest.h")))  MethodPyRandomForest;}
-namespace TMVA{class __attribute__((annotate("$clingAutoload$TMVA/MethodPyTorch.h")))  MethodPyTorch;}
+namespace TMVA{class  __attribute__((annotate("$clingAutoload$TMVA/PyMethodBase.h")))  __attribute__((annotate("$clingAutoload$TMVA/MethodPyAdaBoost.h")))  PyMethodBase;}
+namespace TMVA{class  __attribute__((annotate("$clingAutoload$TMVA/MethodPyAdaBoost.h")))  MethodPyAdaBoost;}
+namespace TMVA{class  __attribute__((annotate("$clingAutoload$TMVA/MethodPyGTB.h")))  MethodPyGTB;}
+namespace TMVA{class  __attribute__((annotate("$clingAutoload$TMVA/MethodPyKeras.h")))  MethodPyKeras;}
+namespace TMVA{class  __attribute__((annotate("$clingAutoload$TMVA/MethodPyRandomForest.h")))  MethodPyRandomForest;}
+namespace TMVA{class  __attribute__((annotate("$clingAutoload$TMVA/MethodPyTorch.h")))  MethodPyTorch;}
+#pragma diagnostic pop
 )DICTFWDDCLS";
     static const char* payloadCode = R"DICTPAYLOAD(
 #line 1 "libPyMVA dictionary payload"
@@ -723,6 +724,9 @@ namespace TMVA{class __attribute__((annotate("$clingAutoload$TMVA/MethodPyTorch.
 #ifndef ROOT_SUPPORT_CLAD
   #define ROOT_SUPPORT_CLAD 1
 #endif
+#ifndef R__DUMMY_CXX_STANDARD_17
+  #define R__DUMMY_CXX_STANDARD_17 1
+#endif
 
 #define _BACKWARD_BACKWARD_WARNING_H
 // Inline headers
