@@ -4,11 +4,11 @@
 #define R__NO_DEPRECATION
 
 /*******************************************************************/
-#include <stddef.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
+#include <cstddef>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <cassert>
 #define G__DICTIONARY
 #include "ROOT/RConfig.hxx"
 #include "TClass.h"
@@ -44,6 +44,7 @@
 #include "TMVA/BatchGenerator/RBatchGenerator.hxx"
 #include "TMVA/BatchGenerator/RBatchLoader.hxx"
 #include "TMVA/BatchGenerator/RChunkLoader.hxx"
+#include "TMVA/BatchGenerator/RChunkConstructor.hxx"
 #include "RConfigure.h"
 
 // Header files passed via #pragma extra_include
@@ -432,12 +433,12 @@ namespace {
 "TMVA/BatchGenerator/RBatchGenerator.hxx",
 "TMVA/BatchGenerator/RBatchLoader.hxx",
 "TMVA/BatchGenerator/RChunkLoader.hxx",
+"TMVA/BatchGenerator/RChunkConstructor.hxx",
 nullptr
     };
     static const char* includePaths[] = {
 "/build/root/src/build-cuda/include",
 "/usr/include",
-"/usr/include",
 "/build/root/src/build-cuda/include/",
 nullptr
     };
