@@ -62,10 +62,6 @@ kC_VSCROLL, kSB_SLIDERTRACK, position, 0
 Pixmap_t TGScrollBar::fgBckgndPixmap = 0;
 Int_t    TGScrollBar::fgScrollBarWidth = kDefaultScrollBarWidth;
 
-ClassImp(TGScrollBarElement);
-ClassImp(TGScrollBar);
-ClassImp(TGHScrollBar);
-ClassImp(TGVScrollBar);
 
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -344,7 +340,7 @@ TGScrollBar::TGScrollBar(const TGWindow *p, UInt_t w, UInt_t h,
                          kButtonReleaseMask | kPointerMotionMask, kNone, kNone);
 
    fDragging = kFALSE;
-   fX0 = fY0 = (fgScrollBarWidth = TMath::Max(fgScrollBarWidth, 5));
+   fX0 = fY0 = (fgScrollBarWidth = std::max(fgScrollBarWidth, 5));
    fPos = 0;
 
    fSliderSize  = 50;
@@ -461,7 +457,7 @@ TGHScrollBar::TGHScrollBar(const TGWindow *p, UInt_t w, UInt_t h,
                            UInt_t options, ULong_t back) :
     TGScrollBar(p, w, h, options, back, "arrow_left.xpm", "arrow_right.xpm")
 {
-   fRange = TMath::Max((Int_t) w - (fgScrollBarWidth << 1), 1);
+   fRange = std::max((Int_t) w - (fgScrollBarWidth << 1), 1);
    fPsize = fRange >> 1;
    fEditDisabled |= kEditDisableHeight;
 }
@@ -514,13 +510,13 @@ Bool_t TGHScrollBar::HandleButton(Event_t *event)
    if (event->fType == kButtonPress) {
       if (event->fCode == kButton3) {
          fX0 = event->fX - fSliderSize/2;
-         fX0 = TMath::Max(fX0, fgScrollBarWidth);
-         fX0 = TMath::Min(fX0, fgScrollBarWidth + fSliderRange);
+         fX0 = std::max(fX0, fgScrollBarWidth);
+         fX0 = std::min(fX0, fgScrollBarWidth + fSliderRange);
          ULong_t pos = (ULong_t)(fX0 - fgScrollBarWidth) * (ULong_t)(fRange-fPsize) / (ULong_t)fSliderRange;
          fPos = (Int_t)pos;
 
-         fPos = TMath::Max(fPos, 0);
-         fPos = TMath::Min(fPos, fRange-fPsize);
+         fPos = std::max(fPos, 0);
+         fPos = std::min(fPos, fRange-fPsize);
          fSlider->Move(fX0, 0);
 
          SendMessage(fMsgWindow, MK_MSG(kC_HSCROLL, kSB_SLIDERTRACK), fPos, 0);
@@ -562,13 +558,13 @@ Bool_t TGHScrollBar::HandleButton(Event_t *event)
          else if (event->fX > fX0+fSliderSize && event->fX < (Int_t)fWidth-fgScrollBarWidth)
             fPos += fPsize;
 
-         fPos = TMath::Max(fPos, 0);
-         fPos = TMath::Min(fPos, fRange-fPsize);
+         fPos = std::max(fPos, 0);
+         fPos = std::min(fPos, fRange-fPsize);
 
-         fX0 = fgScrollBarWidth + fPos * fSliderRange / TMath::Max(fRange-fPsize, 1);
+         fX0 = fgScrollBarWidth + fPos * fSliderRange / std::max(fRange-fPsize, 1);
 
-         fX0 = TMath::Max(fX0, fgScrollBarWidth);
-         fX0 = TMath::Min(fX0, fgScrollBarWidth + fSliderRange);
+         fX0 = std::max(fX0, fgScrollBarWidth);
+         fX0 = std::min(fX0, fgScrollBarWidth + fSliderRange);
 
          fSlider->Move(fX0, 0);
 
@@ -593,8 +589,8 @@ Bool_t TGHScrollBar::HandleButton(Event_t *event)
 
       fDragging = kFALSE;
 
-      fPos = TMath::Max(fPos, 0);
-      fPos = TMath::Min(fPos, fRange-fPsize);
+      fPos = std::max(fPos, 0);
+      fPos = std::min(fPos, fRange-fPsize);
 
       SendMessage(fMsgWindow, MK_MSG(kC_HSCROLL, kSB_SLIDERPOS), fPos, 0);
       PositionChanged(fPos);
@@ -614,14 +610,14 @@ Bool_t TGHScrollBar::HandleMotion(Event_t *event)
       fX0 = event->fX - fXp;
       fY0 = event->fY - fYp;
 
-      fX0 = TMath::Max(fX0, fgScrollBarWidth);
-      fX0 = TMath::Min(fX0, fgScrollBarWidth + fSliderRange);
+      fX0 = std::max(fX0, fgScrollBarWidth);
+      fX0 = std::min(fX0, fgScrollBarWidth + fSliderRange);
       fSlider->Move(fX0, 0);
       ULong_t pos = (ULong_t)(fX0 - fgScrollBarWidth) * (ULong_t)(fRange-fPsize) / (ULong_t)fSliderRange;
       fPos = (Int_t)pos;
 
-      fPos = TMath::Max(fPos, 0);
-      fPos = TMath::Min(fPos, fRange-fPsize);
+      fPos = std::max(fPos, 0);
+      fPos = std::min(fPos, fRange-fPsize);
 
       SendMessage(fMsgWindow, MK_MSG(kC_HSCROLL, kSB_SLIDERTRACK), fPos, 0);
       PositionChanged(fPos);
@@ -634,21 +630,21 @@ Bool_t TGHScrollBar::HandleMotion(Event_t *event)
 
 void TGHScrollBar::SetRange(Int_t range, Int_t page_size)
 {
-   fRange = TMath::Max(range, 1);
-   fPsize = TMath::Max(page_size, 0);
-   fPos = TMath::Max(fPos, 0);
-   fPos = TMath::Min(fPos, fRange-fPsize);
+   fRange = std::max(range, 1);
+   fPsize = std::max(page_size, 0);
+   fPos = std::max(fPos, 0);
+   fPos = std::min(fPos, fRange-fPsize);
 
-   fSliderSize = TMath::Max(fPsize * (fWidth - (fgScrollBarWidth << 1)) /
+   fSliderSize = std::max(fPsize * (fWidth - (fgScrollBarWidth << 1)) /
                             fRange, (UInt_t) 6);
-   fSliderSize = TMath::Min((UInt_t)fSliderSize, fWidth - (fgScrollBarWidth << 1));
+   fSliderSize = std::min((UInt_t)fSliderSize, fWidth - (fgScrollBarWidth << 1));
 
-   fSliderRange = TMath::Max(fWidth - (fgScrollBarWidth << 1) - fSliderSize,
+   fSliderRange = std::max(fWidth - (fgScrollBarWidth << 1) - fSliderSize,
                              (UInt_t) 1);
 
-   fX0 = fgScrollBarWidth + fPos * fSliderRange / TMath::Max(fRange-fPsize, 1);
-   fX0 = TMath::Max(fX0, fgScrollBarWidth);
-   fX0 = TMath::Min(fX0, fgScrollBarWidth + fSliderRange);
+   fX0 = fgScrollBarWidth + fPos * fSliderRange / std::max(fRange-fPsize, 1);
+   fX0 = std::max(fX0, fgScrollBarWidth);
+   fX0 = std::min(fX0, fgScrollBarWidth + fSliderRange);
 
    fSlider->Move(fX0, 0);
    fSlider->Resize(fSliderSize, fgScrollBarWidth);
@@ -667,12 +663,12 @@ void TGHScrollBar::SetRange(Int_t range, Int_t page_size)
 
 void TGHScrollBar::SetPosition(Int_t pos)
 {
-   fPos = TMath::Max(pos, 0);
-   fPos = TMath::Min(pos, fRange-fPsize);
+   fPos = std::max(pos, 0);
+   fPos = std::min(pos, fRange-fPsize);
 
-   fX0 = fgScrollBarWidth + fPos * fSliderRange / TMath::Max(fRange-fPsize, 1);
-   fX0 = TMath::Max(fX0, fgScrollBarWidth);
-   fX0 = TMath::Min(fX0, fgScrollBarWidth + fSliderRange);
+   fX0 = fgScrollBarWidth + fPos * fSliderRange / std::max(fRange-fPsize, 1);
+   fX0 = std::max(fX0, fgScrollBarWidth);
+   fX0 = std::min(fX0, fgScrollBarWidth + fSliderRange);
 
    fSlider->Move(fX0, 0);
    fSlider->Resize(fSliderSize, fgScrollBarWidth);
@@ -690,7 +686,7 @@ TGVScrollBar::TGVScrollBar(const TGWindow *p, UInt_t w, UInt_t h,
                            UInt_t options, ULong_t back) :
     TGScrollBar(p, w, h, options, back, "arrow_up.xpm", "arrow_down.xpm")
 {
-   fRange = TMath::Max((Int_t) h - (fgScrollBarWidth << 1), 1);
+   fRange = std::max((Int_t) h - (fgScrollBarWidth << 1), 1);
    fPsize = fRange >> 1;
    fEditDisabled |= kEditDisableWidth;
 }
@@ -744,13 +740,13 @@ Bool_t TGVScrollBar::HandleButton(Event_t *event)
    if (event->fType == kButtonPress) {
       if (event->fCode == kButton3) {
          fY0 = event->fY - fSliderSize/2;
-         fY0 = TMath::Max(fY0, fgScrollBarWidth);
-         fY0 = TMath::Min(fY0, fgScrollBarWidth + fSliderRange);
+         fY0 = std::max(fY0, fgScrollBarWidth);
+         fY0 = std::min(fY0, fgScrollBarWidth + fSliderRange);
          ULong_t pos = (ULong_t)(fY0 - fgScrollBarWidth) * (ULong_t)(fRange-fPsize) / (ULong_t)fSliderRange;
          fPos = (Int_t)pos;
 
-         fPos = TMath::Max(fPos, 0);
-         fPos = TMath::Min(fPos, fRange-fPsize);
+         fPos = std::max(fPos, 0);
+         fPos = std::min(fPos, fRange-fPsize);
          fSlider->Move(0, fY0);
 
          SendMessage(fMsgWindow, MK_MSG(kC_VSCROLL, kSB_SLIDERTRACK), fPos, 0);
@@ -792,14 +788,14 @@ Bool_t TGVScrollBar::HandleButton(Event_t *event)
          else if (event->fY > fY0+fSliderSize && event->fY < (Int_t)fHeight-fgScrollBarWidth)
             fPos += fPsize;
 
-         fPos = TMath::Max(fPos, 0);
-         fPos = TMath::Min(fPos, fRange-fPsize);
+         fPos = std::max(fPos, 0);
+         fPos = std::min(fPos, fRange-fPsize);
 
-         ULong_t y0 = (ULong_t)fgScrollBarWidth + (ULong_t)fPos * (ULong_t)fSliderRange / (ULong_t)TMath::Max(fRange-fPsize, 1);
+         ULong_t y0 = (ULong_t)fgScrollBarWidth + (ULong_t)fPos * (ULong_t)fSliderRange / (ULong_t)std::max(fRange-fPsize, 1);
          fY0 = (Int_t)y0;
 
-         fY0 = TMath::Max(fY0, fgScrollBarWidth);
-         fY0 = TMath::Min(fY0, fgScrollBarWidth + fSliderRange);
+         fY0 = std::max(fY0, fgScrollBarWidth);
+         fY0 = std::min(fY0, fgScrollBarWidth + fSliderRange);
 
          fSlider->Move(0, fY0);
 
@@ -824,8 +820,8 @@ Bool_t TGVScrollBar::HandleButton(Event_t *event)
 
       fDragging = kFALSE;
 
-      fPos = TMath::Max(fPos, 0);
-      fPos = TMath::Min(fPos, fRange-fPsize);
+      fPos = std::max(fPos, 0);
+      fPos = std::min(fPos, fRange-fPsize);
 
       SendMessage(fMsgWindow, MK_MSG(kC_VSCROLL, kSB_SLIDERPOS), fPos, 0);
       PositionChanged(fPos);
@@ -846,14 +842,14 @@ Bool_t TGVScrollBar::HandleMotion(Event_t *event)
       fX0 = event->fX - fXp;
       fY0 = event->fY - fYp;
 
-      fY0 = TMath::Max(fY0, fgScrollBarWidth);
-      fY0 = TMath::Min(fY0, fgScrollBarWidth + fSliderRange);
+      fY0 = std::max(fY0, fgScrollBarWidth);
+      fY0 = std::min(fY0, fgScrollBarWidth + fSliderRange);
       fSlider->Move(0, fY0);
       ULong_t pos = (ULong_t)(fY0 - fgScrollBarWidth) * (ULong_t)(fRange-fPsize) / fSliderRange;
       fPos = (Int_t)pos;
 
-      fPos = TMath::Max(fPos, 0);
-      fPos = TMath::Min(fPos, fRange-fPsize);
+      fPos = std::max(fPos, 0);
+      fPos = std::min(fPos, fRange-fPsize);
 
       SendMessage(fMsgWindow, MK_MSG(kC_VSCROLL, kSB_SLIDERTRACK), fPos, 0);
       PositionChanged(fPos);
@@ -866,22 +862,22 @@ Bool_t TGVScrollBar::HandleMotion(Event_t *event)
 
 void TGVScrollBar::SetRange(Int_t range, Int_t page_size)
 {
-   fRange = TMath::Max(range, 1);
-   fPsize = TMath::Max(page_size, 0);
-   fPos = TMath::Max(fPos, 0);
-   fPos = TMath::Min(fPos, fRange-fPsize);
+   fRange = std::max(range, 1);
+   fPsize = std::max(page_size, 0);
+   fPos = std::max(fPos, 0);
+   fPos = std::min(fPos, fRange-fPsize);
 
-   fSliderSize = TMath::Max(fPsize * (fHeight - (fgScrollBarWidth << 1)) /
+   fSliderSize = std::max(fPsize * (fHeight - (fgScrollBarWidth << 1)) /
                             fRange, (UInt_t) 6);
-   fSliderSize = TMath::Min((UInt_t)fSliderSize, fHeight - (fgScrollBarWidth << 1));
+   fSliderSize = std::min((UInt_t)fSliderSize, fHeight - (fgScrollBarWidth << 1));
 
-   fSliderRange = TMath::Max(fHeight - (fgScrollBarWidth << 1) - fSliderSize,
+   fSliderRange = std::max(fHeight - (fgScrollBarWidth << 1) - fSliderSize,
                              (UInt_t)1);
 
-   ULong_t y0 = (ULong_t)fgScrollBarWidth + (ULong_t)fPos * (ULong_t)fSliderRange / (ULong_t)TMath::Max(fRange-fPsize, 1);
+   ULong_t y0 = (ULong_t)fgScrollBarWidth + (ULong_t)fPos * (ULong_t)fSliderRange / (ULong_t)std::max(fRange-fPsize, 1);
    fY0 = (Int_t)y0;
-   fY0 = TMath::Max(fY0, fgScrollBarWidth);
-   fY0 = TMath::Min(fY0, fgScrollBarWidth + fSliderRange);
+   fY0 = std::max(fY0, fgScrollBarWidth);
+   fY0 = std::min(fY0, fgScrollBarWidth + fSliderRange);
 
    fSlider->Move(0, fY0);
    fSlider->Resize(fgScrollBarWidth, fSliderSize);
@@ -901,13 +897,13 @@ void TGVScrollBar::SetRange(Int_t range, Int_t page_size)
 
 void TGVScrollBar::SetPosition(Int_t pos)
 {
-   fPos = TMath::Max(pos, 0);
-   fPos = TMath::Min(pos, fRange-fPsize);
+   fPos = std::max(pos, 0);
+   fPos = std::min(pos, fRange-fPsize);
 
-   ULong_t y0 = (ULong_t)fgScrollBarWidth + (ULong_t)fPos * (ULong_t)fSliderRange / (ULong_t)TMath::Max(fRange-fPsize, 1);
+   ULong_t y0 = (ULong_t)fgScrollBarWidth + (ULong_t)fPos * (ULong_t)fSliderRange / (ULong_t)std::max(fRange-fPsize, 1);
    fY0 = (Int_t)y0;
-   fY0 = TMath::Max(fY0, fgScrollBarWidth);
-   fY0 = TMath::Min(fY0, fgScrollBarWidth + fSliderRange);
+   fY0 = std::max(fY0, fgScrollBarWidth);
+   fY0 = std::min(fY0, fgScrollBarWidth + fSliderRange);
 
    fSlider->Move(0, fY0);
    fSlider->Resize(fgScrollBarWidth, fSliderSize);
